version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
   
   ----------------------Information about this code file-----------------------
   tasks : Download and prepare bilateral trade data from input-output tables.
   source: World Input-Output Database (2016 Release) - World Input-Output Tables,
		   https://doi.org/10.34894/PJ2M1C
		   https://dataverse.nl/api/access/datafile/199103
   access: 10 May 2024
   input : "$data/wiod/WIOTXXXX_October16_ROW.dta" where XXXX is year 2000-2014
		   in "WIOTS_in_STATA.zip"
   output: "$temp/wiod_trade.dta"
		   "$temp/wiod_sector_codes.dta" (store the WIOD sector codes).
   

   tasks : Download and prepare exchange rates (USD/unit of local currency).
   source: World Input-Output Database (2016 Release) - Exchange Rates, 
		   https://doi.org/10.34894/PJ2M1C
		   https://dataverse.nl/api/access/datafile/199097
   access: 10 May 2024
   input : "$data/wiod/EXR_WIOD_Nov16.xlsx"
   output: "$temp/wiod_exr.dta"
   
   
   tasks : Download and prepare production factors.
   source: World Input-Output Database (2016 Release) - Socio Economic Accounts, 
		   https://doi.org/10.34894/PJ2M1C
		   https://dataverse.nl/api/access/datafile/199095
   access: 10 May 2024
   input : "$data/wiod/WIOD_SEA_Nov16.xlsx"
   output: "$temp/wiod_sea.dta"


   title : Download and prepare gravity variables.
   source: CEPII - Gravity, February 2021 (version 202102),
		   https://www.cepii.fr/CEPII/en/bdd_modele/bdd_modele_item.asp?id=8
		   https://www.cepii.fr/DATA_DOWNLOAD/gravity/legacy/202102/Gravity_dta_V202102.zip
   access: 10 May 2024
   input : "$data/cepii/Gravity_dta_V202102.zip"
   output: "$temp/cepii.dta"

  
   title : Download and prepare TFP, population and GDP variables.
   source: Penn World Table (version 10.0), 
		   https://doi.org/10.15141/S5Q94M
   access: 10 May 2024
   input : "$data/pwt/pwtv100.zip"
   output: "$temp/pwt.dta"

    
   title : Download and prepare RTA variable.
   source: Mario Larch's Regional Trade Agreements Database (version 20241028),
		   https://www.ewf.uni-bayreuth.de/en/research/RTA-data/index.html
   access: 10 November 2024
   input : "$data/larch_rta/rta_20241028_dta.zip"
   output: "$temp/rta_20241028.dta"

   
   tasks : Download and construct R&D spending (per capita) variable.
   source: OECD Main Science and Technology Indicators (update 29 March 2024), 
		   http://oe.cd/msti
   access: 10 May 2024
   input : "$data/oecd_msti/OECD.STI.STP,DSD_MSTI@DF_MSTI,1.2+all.csv"
   output: "$temp/oecd_r&d.dta"
*/


*-------------------------------------------------------------------------------
* Download and store data from different sources (all publicly available)
*-------------------------------------------------------------------------------

*------Download WIOT, SEA & Xrates from World Input-Output Database (WIOD)------
* Define in macro the folder name to store data
local dir $data/wiod

* Create folder to store data
capture mkdir "`dir'"

* Download relevant datasets
/*Note: if you do not have authorisation/internet access to run the code that
  automatically sources the zipped files, comment out the code below & manually 
  download the zipped files from WIOD (https://doi.org/10.34894/PJ2M1C). 
  Also, the command "copy" might not work with older versions of Stata, thus you
  need to comment it out and download the data manually using provided links.
*/
capture copy "https://dataverse.nl/api/access/datafile/199103" "`dir'\WIOTS_in_STATA.zip" 		 // WIOTs in zipped Stata files
capture copy "https://dataverse.nl/api/access/datafile/199097" "`dir'\EXR_WIOD_Nov16.xlsx" 		 // Exchange Rates in xlsx file
capture copy "https://dataverse.nl/api/access/datafile/199095" "`dir'\WIOD_SEA_Nov16.xlsx" 		 // Socio Economic Accounts in xlsx file
capture copy "https://dataverse.nl/file.xhtml?fileId=199088&version=2.0" "`dir'\SEA_Sources.pdf" // Socio Economic Accounts Read Me file in pdf file


*-------Download Gravity February 2021 (version 202102) dataset from CEPII------
* Define in macro the folder name to store data
local dir $data/cepii

* Create folder to store data
capture mkdir "`dir'"

* Download relevant datasets
/*Note: if you do not have authorisation/internet access to run the code that
  automatically sources the zipped files, comment out the code below & manually 
  download the zipped files from CEPII 
  (https://www.cepii.fr/CEPII/en/bdd_modele/bdd_modele_item.asp?id=8). 
  Also, the command "copy" might not work with older versions of Stata, thus you
  need to comment it out and download the data manually using provided links.
*/
capture copy "https://www.cepii.fr/DATA_DOWNLOAD/gravity/legacy/202102/Gravity_dta_V202102.zip" "`dir'\Gravity_dta_V202102.zip" // gravity variables in zipped Stata files


*--------------Download Penn World Table (version 10.0) dataset-----------------
* Define in macro the folder name to store data
local dir $data/pwt

* Create folder to store data
capture mkdir "`dir'"

* Download relevant datasets
/*Note: if you do not have authorisation/internet access to run the code that
  automatically sources the zipped files, comment out the code below & manually 
  download the zipped files from PWT 
  (https://www.rug.nl/ggdc/productivity/pwt/pwt-releases/pwt100?lang=en). 
  Also, the command "copy" might not work with older versions of Stata, thus you
  need to comment it out and download the data manually using provided links.
*/
capture copy "https://www.rug.nl/ggdc/docs/pwt100.dta" "`dir'\pwt100.dta" // PWT in Stata file


*---Download M. Larch's Regional Trade Agreements Database (version 20241028)---
* Define in macro the folder name to store data
local dir $data/larch_rta

* Create folder to store data
capture mkdir "`dir'"

* Download relevant datasets
/*Note: the dataset is continuously updated with new information over time,
  however, there is no versioning and, thus, cannot access older versions once
  an update is made. We accessed and use the "20241028" version.
  if you do not have authorisation/internet access to run the code that
  automatically sources the zipped files, comment out the code below & manually 
  download the zipped files from PWT 
  (https://www.ewf.uni-bayreuth.de/en/research/RTA-data/index.html). 
  Also, the command "copy" might not work with older versions of Stata, thus you
  need to comment it out and download the data manually using provided links.
*/
capture copy "https://www.ewf.uni-bayreuth.de/pool/dokumente/rta_20241028_dta.zip" "`dir'\rta_20241028_dta.zip" // Mario Larch's RTA in zipped Stata file
capture copy "https://www.ewf.uni-bayreuth.de/pool/dokumente/readme_RTA2.pdf" "`dir'\readme_RTA2.pdf" 			// Mario Larch's RTA Read Me file in pdf file


*--------Download data from OECD Main Science and Technology Indicators---------
* Define in macro the folder name to store data
local dir $data/oecd_msti

* Create folder to store data
capture mkdir "`dir'"

* Download relevant datasets
/*Note: we manually select and download from the OECD Main Science & Technology 
  Indicators (update 29 March 2024) data-explorer (http://oe.cd/msti) the 
  relevant variables listed below for all available periods and for the set
  of countries available in WIOD. Data accessed on 10 May 2024 and the selected
  variables include:
	G_PPPCT	 Gross Domestic Expenditure on R&D (GERD) at constant prices and PPP $
	B_PPPCT	 Business Enterprise Expenditure on R&D (BERD) at constant prices and PPP $
	H_PPPCT	 Higher Education Expenditure on R&D (HERD) at constant prices and PPP $
	GV_PPPCT Government Intramural Expenditure on R&D (GOVERD) at constant prices and PPP $
	- All of the above variables are reported in millions
	TOT_POP  Total population in thousands
	File stored in "$data/oecd_msti/OECD.STI.STP,DSD_MSTI@DF_MSTI,1.2+all.csv"
*/


*-------------------------------------------------------------------------------
* Process WIOD 2016 Release - World Input-Output Tables (WIOT)
*-------------------------------------------------------------------------------
* Unzip folders
cd "$data/wiod" 									// change directory to where zipped files are stored
unzipfile WIOTS_in_STATA, replace
cd "$here" 											// reset directory

quietly forvalues year = 2000 / 2014 {
	use "$data/wiod/WIOT`year'_October16_ROW.dta", clear

	* Drop redundant parts from the IO table
	drop if Country == "TOT"
	drop TOT Industry*

	* Rename variables
	tostring RNr, replace format(%02.0f)
	rename v* *
	glevelsof Country, local(levels)
	foreach c of local levels {
		rename `c'* `c'_*
	}
	
	forvalues i = 1/9 {
		rename *_`i' *_0`i'
	}
	
	gen v1 = Country + "_" + RNr
	drop Country RNr Year
	split v1, p(_)
	rename (v11 v12) (exporter sector)

	*------------------------Intermediate input exports-------------------------
	preserve
		drop v1 *57 *58 *59 *60 *61 
		gunique sector
		glevelsof sector, local(sector)
		local first: word 1 of `sector'
		local last: word `r(J)' of `sector'

		foreach var of varlist *_`first' {
			local c = substr("`var'", 1, 3)
			egen exports`c' = rowtotal(`c'_`first'-`c'_`last')
		}
		drop *_*

		* Reshape and rename data
		greshape long exports, i(exporter sector) j(importer) string
		rename exports exports_int
		gen year = `year'
		save "$temp/wiod_intermediate_`year'.dta", replace
	restore
	
	*-------------------------Final demand exports------------------------------
	keep exporter sector *57 *58 *59 *60 *61 

	foreach var of varlist *57 {
		local c = substr("`var'", 1, 3)
		egen exports`c' = rowtotal(`c'_57 `c'_58 `c'_59 `c'_60 `c'_61)
	}
	drop *_*

	* Reshape and rename data
	greshape long exports, i(exporter sector) j(importer) string
	rename exports exports_fin
	
	* Save yearly files
	gen year = `year'
	save "$temp/wiod_final_`year'.dta", replace
	noisily display "Completed: `year'"
}

* Append yearly files and store (for intermediate and final demand)
foreach type in intermediate final {
	local names: dir "$temp/" files "wiod_`type'_*"
	local first: word 1 of `names'
	foreach f of local names {
		if "`f'" == "`first'" use "$temp/`first'", clear
		else append using "$temp/`f'"
		erase "$temp/`f'"
	}
	compress
	save "$temp/wiod_`type'.dta", replace
}

* Merge intermediate input and final demand data
use "$temp/wiod_intermediate.dta", clear
merge 1:1 exporter sector importer year using "$temp/wiod_final.dta", nogen

* Drop ROW due to the unavailability of other key variables needed for the analysis
drop if exporter == "ROW" | importer == "ROW"

* Safeguard: replace negative values for final goods trade to zero (0.078 % of data in final goods trade)
summarize exports*
scalar N = r(N)
summarize if exports_fin < 0
scalar neg = r(N)
display "Share of (final goods trade) observations affected:" %9.4f `=(neg/N)*100' "%"
tabulate sector exporter if exports_fin < 0 
replace exports_fin = 0 if exports_fin < 0

* Construct total exports (intermediates + final)
gen exports_tot = exports_int + exports_fin

* Label variables
order exporter sector importer year
label var exports_int "WIOD2016 WIOT intermediate exports (in millions of USD)"
label var exports_fin "WIOD2016 WIOT final exports (in millions of USD)"
label var exports_tot "WIOD2016 WIOT total exports (in millions of USD)"
drop exports_int exports_fin

* Save
save "$temp/wiod_trade.dta", replace

* Housekeeping
shell erase "$temp\wiod_intermediate.dta"
shell erase "$temp\wiod_final.dta"


*-------------------------------------------------------------------------------
* WIOD Industry Codes (sourced from WIOT)
*-------------------------------------------------------------------------------
use IndustryCode RNr using "$data/wiod/WIOT2000_October16_ROW.dta", clear

* Rename variables
tostring RNr, replace format(%02.0f)
rename (RNr IndustryCode) (sector code)
gduplicates drop

* Save
save "$temp/wiod_sector_codes.dta", replace

* Housekeeping
shell erase "$data\wiod\*.dta"


*-------------------------------------------------------------------------------
* WIOD exchange rates
*-------------------------------------------------------------------------------
* Import & reshape data
import excel "$data/wiod/EXR_WIOD_Nov16.xlsx", sheet("EXR") firstrow clear cellrange(A4:Q47)
drop Country
rename (Acronym _*) (exporter EXR*)
greshape long EXR, i(exporter) j(year)
label var EXR "WIOD2016 Exchange rate in USD per unit of local currency"

* Rename ROM -> ROU (Romania)
replace exporter = "ROU" if exporter == "ROM"

* Save
save "$temp/wiod_exr.dta", replace


*-------------------------------------------------------------------------------
* WIOD Socio-Economic Accounts (SEA) Database 2016 (Labor & Capital)
*-------------------------------------------------------------------------------
import excel using "$data/wiod/WIOD_SEA_Nov16.xlsx", sheet("DATA") firstrow clear

foreach var of varlist E-S { 						// non-available information
	replace `var' = "" if `var' == "NA"
}

destring, replace
renvarlab E-S, label prefix(value)

* Reshape long-wide
greshape long value, i(country variable description code) j(year) 
greshape wide value, i(country description code year) j(variable) string
rename (value* country) (* exporter)

* Merge sector codes
merge m:1 code using "$temp/wiod_sector_codes.dta", nogen keep(matched)

* Keep relevant variables
keep exporter year sector code COMP LAB CAP K EMP

* Label variables
order exporter year sector code
label var EMP	 "SEA2016 Number of persons engaged (thousands)"
label var COMP	 "SEA2016 Compensation of employees (in millions of national currency)"
label var LAB	 "SEA2016 Labour compensation (in millions of national currency)"
label var CAP	 "SEA2016 Capital compensation (in millions of national currency)"
label var K		 "SEA2016 Nominal capital stock (in millions of national currency)"

* Merge exchange rates
merge m:1 exporter year using "$temp/wiod_exr.dta", nogen

* Convert SEA data to USD using exchange rates from WIOD
foreach var in COMP LAB CAP K {
	replace `var' = `var' * EXR
}
drop EXR

* Label variables
label var COMP 	"SEA2016 Compensation of employees (in millions of USD)"
label var LAB 	"SEA2016 Labour compensation (in millions of USD)"
label var CAP 	"SEA2016 Capital compensation (in millions of USD)"
label var K 	"SEA2016 Nominal capital stock (in millions of USD)"

* Check for missing values in inputs
mdesc CAP K LAB COMP EMP

* Safeguard: replace negative values to zero for CAP and K in SEA
quietly foreach var in CAP K {
	count if `var' < 0
	scalar n = r(N)
	count
	noisily display "number of observations with negative values for `var' is `=n' observations or" %9.4f `=(n/r(N))*100' "%"
	* number of observations replaced for CAP is 1819 observations or 5.0359%
	* number of observations replaced for K   is 3 	  observations or 0.0083% (these are for PRT sector 23 years 2012-2014)
	noisily tabulate sector exporter if `var' < 0
	noisily tabulate year if `var' < 0
	replace `var' = 0 if `var' < 0
}

rename code sector_code
label var sector_code "WIOD sector codes"

* Save
save "$temp/wiod_sea.dta", replace


*-------------------------------------------------------------------------------
* Process gravity data from CEPII - February 2021 (version 202102)
*-------------------------------------------------------------------------------
* Unzip folders
cd "$data/cepii" 									// change directory to where zipped files are stored
unzipfile Gravity_dta_V202102, replace
cd "$here" 											// reset directory

use year iso3_o iso3_d dist wto_o wto_d eu_o eu_d using "$data/cepii/Gravity_V202102.dta", clear // load data and keep relevant variables
rename (iso3_o iso3_d) (exporter importer)

* Rename and label relevant variables
foreach var in wto eu {
	gen `var' = (`var'_o == 1 & `var'_d == 1)
	replace `var' = 0 if exporter == importer
	drop `var'_*
}
label var dist 	"CEPII Distance between most populated cities, in km"
label var wto 	"CEPII = 1 if WTO members"
label var eu 	"CEPII = 1 if EU members"

save "$temp/cepii.dta", replace
shell erase "$data\cepii\*.dta"


*-------------------------------------------------------------------------------
* Process PWT v10.0 (TFP)
*-------------------------------------------------------------------------------
use countrycode year ctfp pop cgdpo using "$data/pwt/pwt100.dta", clear
rename countrycode exporter
label var ctfp 	"PWTv10.0 TFP level at current PPPs (USA = 1)"
label var pop 	"PWTv10.0 Population (in millions)"
label var cgdpo "PWTv10.0 Output-side real GDP at current PPPs (in mil. 2017US$)"

* Save
save "$temp/pwt.dta", replace


*-------------------------------------------------------------------------------
* Combine WIOD trade with SEA and other data sources
*-------------------------------------------------------------------------------
use "$temp/wiod_trade.dta", clear

* Merge socio-economic accounts
merge m:1 exporter year sector using "$temp/wiod_sea.dta", nogen

* Check data
gcollapse (sum) X_it = exports_tot , by(exporter sector year) merge
summarize exports_tot X_it if (LAB == 0 & K == 0) & X_it > 0 
summarize exports_tot X_it if (LAB == 0 & K == 0) & X_it > 0 & exports_tot > 0
tabulate sector exporter if (LAB == 0 & K == 0) & X_it > 0 & exports_tot > 0
/* Note: These are cases where capital and labour are zero, but total production 
   in each country-sector-year is strictly positive. These are just numerical 
   approximation errors in the raw data for MLT sector 02 that we make 0.
       Variable |        Obs        Mean    Std. Dev.       Min        Max
   -------------+---------------------------------------------------------
    exports_tot |         28    3.55e-07    1.04e-06   1.08e-19   4.73e-06
           X_it |         28    1.06e-06    1.82e-06   1.08e-19   4.73e-06
*/
* Should not matter for estimations since they are aggregated + very small values
replace exports_tot = 0 if (LAB == 0 & K == 0) & X_it > 0 		// should not matter for estimations since they are aggregated + very small values
gcollapse (sum) X_it = exports_tot , by(exporter sector year) merge replace
summarize exports_tot X_it if (LAB == 0 & K == 0) & X_it > 0
summarize exports_tot X_it if (LAB > 0 & K == 0) & X_it > 0 	// keep when at least one factor of production is positive and there is production
summarize exports_tot X_it if (LAB == 0 & K > 0) & X_it > 0

summarize exports_tot X_it if (LAB == 0 & CAP == 0) & X_it > 0 	// there are still a few missing for the alternative measure of capital
summarize exports_tot X_it if (LAB == 0 & CAP == 0) & X_it > 0 & exports_tot > 0 
tabulate sector exporter if (LAB == 0 & CAP == 0) & X_it > 0 & exports_tot > 0
/*
       Variable |        Obs        Mean    Std. Dev.       Min        Max
   -------------+---------------------------------------------------------
    exports_tot |         34    .0035819    .0123323   7.11e-15   .0700637
           X_it |         34    .1217843           0   .1217843   .1217843

			   |  exporter
		sector |       LVA |     Total
	-----------+-----------+----------
			10 |        34 |        34 
	-----------+-----------+----------
		 Total |        34 |        34 
*/
* Don't replace below; it doesn't matter for estimations since they are aggregated + very small values + robustness only
// replace exports_tot = 0 if (LAB == 0 & CAP == 0) & X_it > 0 	// doesn't matter for estimations since they are aggregated + very small values
summarize exports_tot X_it if (LAB == 0 & CAP == 0) & X_it > 0
summarize exports_tot X_it if (LAB > 0 & CAP == 0) & X_it > 0
summarize exports_tot X_it if (LAB == 0 & CAP > 0) & X_it > 0

summarize exports_tot X_it if (COMP == 0 & K == 0) & X_it > 0 	// there are still a few missing for these production factors
summarize exports_tot X_it if (COMP == 0 & K == 0) & X_it > 0 & exports_tot > 0 
tabulate sector exporter if (COMP == 0 & K == 0) & X_it > 0 & exports_tot > 0

summarize exports_tot X_it if (COMP == 0 & K == 0) & X_it > 0 
summarize exports_tot X_it if (COMP > 0 & K == 0) & X_it > 0
summarize exports_tot X_it if (COMP == 0 & K > 0) & X_it > 0

* Check cases with no production but positives for at least one production factor
tabulate sector exporter if K == 0 & LAB == 0
tabulate sector exporter if K == 0 | LAB == 0 
tabulate sector exporter if K == 0 | LAB == 0 & X_it == 0
* Note: RUS has many sectors, mostly in services that report no production and 
* factors of production across all years. Thus, we drop RUS from the sample.
drop if exporter == "RUS" | importer == "RUS"

* Merge Mario Larch RTA data (all from master get matched)
preserve
	* Unzip folders
	cd "$data/larch_rta" 								// change directory to where zipped files are stored
	unzipfile rta_20241028_dta, replace
	cd "$here" 											// reset directory
restore
merge m:1 exporter importer year using "$data/larch_rta/rta_20241028.dta", keep(master match) nogen
erase "$data/larch_rta/rta_20241028.dta"

* Compute RTA dummy (either fta or cu)
gen rta_ml = (cu == 1 | fta == 1 | cueia == 1 | ftaeia == 1)
label var rta_ml "dummy = 1 if FTA, CU, CU EIA, FTA or EIA = 1. (source Mario Larch RTA database)"
drop rta cu fta psa *eia 

* Merge with CEPII data (all from master get matched)
merge m:1 exporter importer year using "$temp/cepii.dta", keep(master match) nogen 

drop X_it sector_*

* Merge PWTv10.0 data
merge m:1 exporter year using "$temp/pwt.dta", keep(matched) nogen

* Save sectoral data (keep only relevant variables for estimation)
sort exporter sector importer year
compress 
preserve 
	drop ctfp cgdpo pop dist CAP COMP EMP
	compress
	save "$temp/sample_sectoral.dta", replace
restore

* Aggregate to country level and merge other relevant variables
gcollapse (sum) exports* CAP COMP K LAB EMP (firstnm) rta* eu wto ctfp pop dist cgdpo, by(exporter importer year) labelf(#sourcelabel#)

* Save
sort exporter importer year
compress 
save "$temp/sample.dta", replace


* Construct samples for sector groupings
use "$temp/sample_sectoral.dta", clear

* Total economy (01-56)
gen tot = 1

* Agriculture (01; 02; 03)
inlist2 sector, values(01, 02, 03) name(agr)

* Mining & Quarrying (3)
inlist2 sector, values(04) name(min)

* Manufacturing (5-23)
inlist2 sector, values(05, 06, 07, 08, 09, 10, 11, 12, 13, 14, 15, 16, 17, 18, 19, 20, 21, 22, 23) name(man)

* Total services (tradable + non-tradable) - excludes real estate (44) & includes other service activities (54)
inlist2 sector, values(31, 32, 33, 34, 35, 36, 37, 38, 39, 40, 41, 42, 43, 45, 46, 47, 48, 49, 50, 28, 29, 30, 54) name(ser)

* Aggregate sectors at the broad level grouping
foreach sgroup in tot agr min man ser { 			// for different sector groupings
	preserve
		keep if `sgroup' == 1
		gcollapse (sum) exports* LAB K (firstnm) rta* eu wto, by(exporter importer year) labelf(#sourcelabel#)
		summarize K LAB
		sort exporter importer year
		compress
	save "$temp/sample_`sgroup'.dta", replace
	restore
}


*-------------------------------------------------------------------------------
* Construct R&D spending (per capita) variable for each country-year in WIOD
*-------------------------------------------------------------------------------
/* Source: OECD Main Science and Technology Indicators (MSTI database)
   Data downloaded on 10 May 2024 from http://oe.cd/msti
   Frequency of observation: Annual
   Topic: Innovation and technology > Research and development (R&D)
   Last updated: March 29, 2024
   Description: The OECD Main Science and Technology Indicators (MSTI) provide a
   set of indicators that compare the Science and Technology (S&T) performance 
   of OECD member countries and selected non-member economies. The MSTI database
   focuses principally on tracking financial and human resources devoted to 
   research and experimental development (R&D), as defined in the OECD Frascati
   Manual, complemented by additional indicators of outputs and potential outcomes
   of S&T activities, namely patent data and international trade in R&D-intensive
   industries. MSTI also comprises several OECD economic and demographic 
   statistical series which are used to calculate relevant benchmarks that 
   account for differences in the relative size of economies, purchasing power 
   and the effect of inflation.
*/

insheet using "$data/oecd_msti/OECD.STI.STP,DSD_MSTI@DF_MSTI,1.2+all.csv", clear names
keep ref_area measure v10 time_period obs_value unitmultiplier unit_measure pricebase 
keep if inlist(unit_measure, "USD_PPP", "PS")
keep if inlist(unitmultiplier, "Millions", "Thousands")
keep if inlist(measure, "G", "B", "H", "GV", "TOT_POP")
/* Note:	
	G_PPPCT	 Gross Domestic Expenditure on R&D (GERD) at constant prices and PPP $
	B_PPPCT	 Business Enterprise Expenditure on R&D (BERD) at constant prices and PPP $
	H_PPPCT	 Higher Education Expenditure on R&D (HERD) at constant prices and PPP $
	GV_PPPCT Government Intramural Expenditure on R&D (GOVERD) at constant prices and PPP $
	- All of the above variables are reported in millions
	TOT_POP is total population in thousands
*/

replace measure = subinstr(measure, "TOT_", "",.)
replace unit_measure = "USD_PPP_CT" if pricebase == "Constant prices"
replace unit_measure = substr(unit_measure, 4, .)
replace unit_measure = subinstr(unit_measure, "PPP_", "PPP",.)
replace measure = measure + "" + unit_measure

drop v10 unit_measure pricebase unitmultiplier
rename (ref_area time_period obs_value) (exporter year value)

greshape wide value, i(exporter year) j(measure) string
rename value* *
drop *CT

* Merge to see how much we interpolate
merge 1:1 exporter year using "$temp/wiod_exr.dta",
tabulate exporter if _merge == 2 					// set of countries (5) with no information on R&D across all years 
/* 
	   REF_AREA |      Freq.     Percent        Cum.
	------------+-----------------------------------
			BRA |         15       20.00       20.00
			CYP |         15       20.00       40.00
			IDN |         15       20.00       60.00
			IND |         15       20.00       80.00
			MLT |         15       20.00      100.00
	------------+-----------------------------------
		  Total |         75      100.00              
*/

tabulate exporter if _merge == 3 					// set of countries with available information on R&D (at least for 1 year)
gunique exporter if exporter != "RUS" & _merge==3 	// 37 remaining countries
summarize if exporter != "RUS" & _merge==3

* Share of missing information that we interpolate below
count if exporter != "RUS" & _merge==3
scalar N = r(N)
quietly foreach var in G_PPP H_PPP B_PPP GV_PPP {
	count if missing(`var') & exporter != "RUS" & _merge==3
	scalar neg = r(N)
	noisily display "Share of missing data for `var' is" %9.2f `=(neg/N)*100' "%"
}
/*  
	Share of missing data for G_PPP is 5.05%
	Share of missing data for H_PPP is 4.14%
	Share of missing data for B_PPP is 4.32%
	Share of missing data for GV_PPP is 3.96% 
*/
drop _merge

* Linear interpolation of missing information
foreach var of varlist *PPP* POP {
	* Linear interpolation using the known values of yvar before and after any missing values
	bys exporter (year): mipolate `var' year, gen(`var'_check)
	drop `var'
	rename *_check *
	
	* Forward interpolation
	bys exporter (year): mipolate `var' year, gen(`var'_check) forward
	drop `var'
	rename *_check *
	
	* Backward interpolation
	bys exporter (year): mipolate `var' year, gen(`var'_check) backward
	drop `var'
	rename *_check *
}

keep if inrange(year, 2000, 2014) 					// keep WIOD years

* Check
merge 1:1 exporter year using "$temp/wiod_exr.dta"
tabulate exporter if _merge == 2 					// check set of countries (0) with no information on R&D across all years
drop _merge

* Save
sort exporter year
compress
save "$temp/oecd_msti.dta", replace


*-------------------------------------------------------------------------------
* Housekeeping
*-------------------------------------------------------------------------------
shell erase "$temp\wiod_*.dta"
shell erase "$temp\X*.dta"
erase "$temp/pwt.dta"
erase "$temp/cepii.dta"
erase "$temp/sample_sectoral.dta"
