version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   title  : Estimate & store results presented in manuscript Tables 1 and 3; & 
			online appendix Table C.1 (except for columns 6, 7, and 8).
   source : Regression results, 
   input  : $temp/sample.dta
   output : $output_est/XXX.ster
			$output_est/XXX.dta
			where XXX refers to the name of the respective file.
*/
*-------------------------------------------------------------------------------


*--------------------------Define macros for bootstrap--------------------------
global seed 	1658203945 							// set random-# seed for replicability of results
global B		100 								// # of bootstrap replications


*------------------------------Define programmes--------------------------------
* Set program to store bootstrap replication coefficients
capture program drop boot_store
program define boot_store
	local cmd = e(cmd) 								// estimation command name, e.g. ppmlhdfe, gmm
	
	* Get a list of coefficients without the dummy variables (for gmm only)
	if "`cmd'" == "gmm" {
		local colfullnames_b: colfullnames e(b) 	// extract the full_name of the columns
		local comma 
		foreach i in `colfullnames_b' {
			local first_two = substr("`i'", 1, 2)
			if "`first_two'" != "xb" & "`first_two'" != "b0" {
				local b_nodummies `b_nodummies'`comma' _b[`i'] 
				local b_colnames `b_colnames' `i' 
				local comma ,
			}
		}
		
		* Store bootstrap replication coefficients (excluding dummy variables)
		matrix b = (`b_nodummies') 					// estimated parameters
		matrix colnames b = `b_colnames'
	}

	* Store bootstrap replication coefficients
	else matrix b = e(b) 							// estimated parameters

	* Post bootstrap replication results
	ereturn post b
end


*-------------------------------------------------------------------------------
clear frames
use "$temp/sample.dta", clear
set seed $seed 										// set random-# seed for replicability of results

* Exporter, importer, year and (assymetric) pair groups
gegen i  = group(exporter)
gegen j  = group(importer)
gegen t  = group(year)
gegen ij = group(exporter importer)

* Symmetric pair groups
gen first  = cond(i < j, i, j)
gen second = cond(i < j, j, i)
gegen ij_symm = group(first second)
tabulate exporter importer if ij_symm == 1 			// check: group = 1 is domestic pair AUS-AUS
replace ij_symm = 1 if i == j 						// treat domestic pairs the same
drop first second

* Construct border dummies 
gen brdr = (exporter != importer)
label var brdr "dummy = 1 for international trade, i.e. i==j, and 0 for intranational trade"

* Create & copy current data to new frame (call in each bootstrap replication)
frame copy default boot0 

* Bootstrap replication weights for Bayesian bootstrap (Rubin, 1981) also known
* as exchangeably weighted bootstrap schemes
gen bw_0 = 1 										// weight for original sample regressions
exbsample $B, seed($seed) stub(bw_) cluster(ij) 	// continuous weights for bayesian sampling
/* Note: draws from an exponential distribution with unit mean (alternatively 
   draw from a Poisson distribution). Drawing from the exponential distribution
   generates strictly positive, non-integer weights. Draws from the exponential 
   distribution can be seen as continuous (smoothed) versions of Poisson draws. 
   The advantage of exponential draws is absence of zero weights: all observations
   from the original data are kept in bootstrap resamples, albeit with possibly 
   small weights. This can have practical computational advantages such as when
   computing MR terms. In both cases, replication weights are, by default, scaled
   to sum to the sample size N.
   Observations from the same cluster all have the same weight and weights sum 
   to the number of clusters.
 */

* Copy bootstrap replication weights to a new frame (call in each bootstrap replication)
frame put ij t bw_*, into(boot_weights)
drop bw_*


*-------------------------------------------------------------------------------
* Stage 1: Run standard gravity and compute MR terms & other relevant variables
*-------------------------------------------------------------------------------
* Program to bootstrap 1st stage
* Implement Bayesian bootstrap (Rubin, 1981) also known as exchangeably weighted
* bootstrap scheme where we apply weighted regressions using weights drawn from 
* the exponential distribution generating strictly positive, non-integer weights
capture program drop boot_bayes
program boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	frlink 1:1 ij t, frame(boot_weights) 			// create linkages to frame with bootstrap replication weights
	frget w = bw_$b, from(boot_weights) 			// copy relevant bootstrap weight from linked frame and rename it to w
 	gen exports_tot_w = exports_tot * w 			// adjust dependend variable for weighted ppml regression below

	* Stage 1: Standard gravity
	ppmlhdfe exports_tot_w rta_ml eu wto 1.brdr#i(3/15)bn.t, exposure(w) a(phi_it = i#t  psi_jt = j#t  miu_ij = ij_symm##c.t, savefe) d(fe) // note: all predicitons include weights
	* Note: gives same results as command below, but faster
	// ppmlhdfe exports_tot rta_ml eu wto 1.brdr#i(3/15)bn.t [w = w], a(phi_it = i#t  psi_jt = j#t  miu_ij = ij_symm##c.t, savefe) d(fe) 	// note: all predicitons do not include weights

	* Store bootstrap replication coefficients
	matrix b = e(b) 								// estimated parameters

	* Predictions
	predict exports_tot_hat_w, mu 					// expected trade flow value, i.e. fitted values (includes weights)
	predict xb, xb 									// linear prediction: includes constant and weights, and excludes FEs
	replace xb = xb - _b[_cons] - ln(w)				// linear prediction: excludes constant, FEs and weights
	rename miu_ijSlope1 miu_ij_trend 				// symmetric pair-specific trade cost time trends
	gen d_brdr = xb - (_b[rta_ml] * rta_ml + _b[eu] * eu + _b[wto] * wto) // border-time FEs

	* Checks
	gen res = (exports_tot_w / exports_tot_hat_w) * w 
	summarize exports_tot* 							// actual and predicted trade should have the same mean (up to rounding error)
	summarize res 									// residuals should have a mean of ~ 1
	drop res fe

	* Multilateral resistances
	* (i) normalize to get rid of the constant (absorb into the symmetric pair FE)
	/* Note: the computed constant in reghdfe is a nuisance term that we normalise 
	   to zero i.e. regressions without constant.
	   - To "normalize" the constant to zero, we subtract _b[_cons] from each 
		 observation. For all observations, this will zero out _b[_cons].
	   - Recall exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
	   - Thus, if we subtract _b[_cons] from _b[_cons], we must add _b[_cons]
		 to the fixed effects. We do this by adding it to the symmetric pair FE.
		 (it does not really matter in which FE you absorb it).
	*/
	replace miu_ij = miu_ij + _b[_cons]

	* (ii) normalize symmetric pair-specific trade costs (trends) by internal symmetric pair-specific trade costs (trends)
	/* Note: the border-time dummies are already defined wrt. to domestic trade and
	   have selected the base dummies to be dropped in the regression
	*/
	gen todrop = miu_ij if i == j
	gen todrop2 = miu_ij_trend if i == j
	gegen miu_ii = firstnm(todrop), by(i) 			// (logged) internal symmetric pair-specific trade costs for exporters
	gegen miu_jj = firstnm(todrop), by(j) 			// (logged) internal symmetric pair-specific trade costs for importers
	gegen miu_ii_trend = firstnm(todrop2), by(i) 	// (logged) internal symmetric pair-specific trade cost trends for exporters
	gegen miu_jj_trend = firstnm(todrop2), by(j) 	// (logged) internal symmetric pair-specific trade cost trends for importers
	drop todrop*

	/*
	* Check
	bys t i (j): egen miu_ii2 = sum(miu_ij * (i == j))
	bys t j (i): egen miu_jj2 = sum(miu_ij * (i == j))
	bys t i (j): egen miu_ii2_trend = sum(miu_ij_trend * (i == j))
	bys t j (i): egen miu_jj2_trend = sum(miu_ij_trend * (i == j))
	assert(miu_ii == miu_ii2) & (miu_jj == miu_jj2) & (miu_ii_trend == miu_ii2_trend) & (miu_jj_trend == miu_jj2_trend)
	*/

	/* Note: we have computed (logged) internal symmetric pair-specific trade costs 
	   (miu_ij) for exporters (miu_ii) and importers (miu_jj).
	   - To "normalize" miu_ij to zero, we subtract miu_ii/2 + miu_jj/2 from each 
		 miu_ij. For i=j, this will zero out miu_ij.
	   - Recall, exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
		 - Thus, if we subtract miu_ii/2 for each observation where i is the exporter,
		   we must add miu_ii/2 to the phi_it's for that exporter.
		 - Likewise, if we subtract miu_jj/2 from each observation where j is the 
		   importer, we must ADD miu_jj/2 to the psi_jt's for that importer. 
	   - This 50-50 split of the fixed effects for the normalization of miu_ij is not 
		 the only possibility. Other allocations could be chosen, e.g. 100-0, 30-70,
		 which should give the same results.
	   - To normalise symmetric pair-specific trade cost trends (miu_ij_trend) to 0
		 for internal trade, we follow the same steps from above.
	*/

	replace miu_ij = miu_ij - miu_ii / 2 - miu_jj / 2 
	replace miu_ij_trend = miu_ij_trend*t  - (miu_ii_trend*t ) / 2 - (miu_jj_trend*t ) / 2

	replace phi_it = phi_it + miu_ii / 2 + (miu_ii_trend*t ) / 2
	replace psi_jt = psi_jt + miu_jj / 2 + (miu_jj_trend*t ) / 2
	capture drop miu_ii* miu_jj*

	summarize miu_ij* d_brdr if i == j 				// check: should be zero for internal trade (equivalent to dropping dummies for internal trade in a regression without a constant)
	* Note: d_brdr is already normalised; base groups directly dropped in regression

	* (iii) solve the system of MRs (set the reference country's IMR to 1)
	/* Note: set importer USA as reference country, i.e. as if you drop the importer
	   dummy for USA (for all years) in a regression without a constant and then do
	   the typical normalization for solving the system of MRs.
	*/

	* Gross output and expenditure (logged)
	gegen Y_i = sum(exports_tot_w), by(i t) 		// gross output at exporter-time level
	gegen E_j = sum(exports_tot_w), by(j t) 		// expenditure at importer-time level
	gen ln_Y_i = ln(Y_i)
	gen ln_E_j = ln(E_j)

	local cref USA 									// choose reference country
	gegen E_j_ref = sum(exports_tot_w) if importer == "`cref'", by(t) // expenditure at importer-reference-country-time level
	gegen E_j_ref = firstnm(E_j_ref), by(t) replace

	gen psi_jt_ref = psi_jt if importer == "`cref'"
	gegen psi_jt_ref = firstnm(psi_jt_ref), by(t) replace

	replace phi_it = phi_it + psi_jt_ref - ln(E_j_ref)
	replace psi_jt = psi_jt - psi_jt_ref + ln(E_j_ref)
	/* Note: this is the typical normalization for solving the system of MRs, i.e.
	   get rid of the constant and set `cref' as the reference country.
	*/

	* Check: should return 1's for the FEs and zero for the constant
	ppmlhdfe exports_tot_w rta_ml eu wto 1.brdr#i(3/15)bn.t phi_it psi_jt miu_ij miu_ij_trend, exposure(w)
	ppmlhdfe exports_tot_w rta_ml eu wto d_brdr 			phi_it psi_jt miu_ij miu_ij_trend, exposure(w)

	* Outward and inward multilateral resistances (MRs in logs)
	gen ln_OMR_i = ln_Y_i - phi_it
	gen ln_IMR_j = ln_E_j - psi_jt

	* Check: reference country IMR should be equal to 1 and ln_IMR equal to 0
	noisily summarize ln_IMR_j if importer == "`cref'"

	* Bilateral trade cost vector (logged)
	gen ln_tau = xb + miu_ij + miu_ij_trend			// include relevant FEs to the linear prediction vector (xb)

	* Relevant constrained importer-time FEs & bilateral trade costs
	gen ln_tau_psi_jt = ln_tau + psi_jt

	* Production function variables and trade in logs
	gen ln_A_i = ln(ctfp)
	gen ln_L_i = ln(LAB)
	gen ln_K_i = ln(K)
	gen ln_exports_tot_hat_w = ln(exports_tot_hat_w)

	* Housekeeping
	drop xb *Y_i E_j *_ref miu* d_brdr phi_it

	* Post bootstrap replication results from stage 1
	ereturn post b	

	preserve
		keep ij t w *tot_* psi_jt ln_*
		save "$temp/stage1_brep$b.dta", replace
	restore

	* Housekeeping 
	drop ln_* psi* *tot_* w boot_weights

	frame change default 							// change to default dataset

	global b = $b + 1 								// update count indicator
end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/stage1_breps_bayes",replace) reps($B) seed($seed): boot_bayes 
estimates save "$output_est/stage1_boot_bayes", replace // save results in .ster file and call back any time for constructing result tables


*-------------------------------------------------------------------------------
* Stage 2: Estimating equation
*-------------------------------------------------------------------------------
* Create and run programs to bootstrap 2nd stage regressions

*-------------------------------------------------------------------------------
* Bilateral trade costs: Flexible
* Importer-time FEs    : Flexible
local model flex_flex 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i)

	* Estimation
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i rta_ml eu wto, a(i j#t ij_symm##c.t brdr#t) exposure(w)
	boot_store 										// store bootstrap replication coefficients

	* Housekeeping 
	drop w *tot_w ln_* // stage1_*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Bilateral trade costs: Flexible
* Importer-time FEs    : Somewhat constrained
local model flex_mid 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_*_j)
	
	* Estimation
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i rta_ml eu wto ln_E_j ln_IMR_j, a(i t ij_symm##c.t brdr#t) exposure(w)
	boot_store 										// store bootstrap replication coefficients

	* Housekeeping 
	drop w *tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Bilateral trade costs: Flexible
* Importer-time FEs    : Fully constrained
local model flex_cons 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i psi*)
	
	* Estimation
	gen psi_jt_w = psi_jt + ln(w)
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i rta_ml eu wto, a(i t ij_symm##c.t brdr#t) offset(psi_jt_w)
	boot_store 										// store bootstrap replication coefficients

	* Housekeeping
	drop w *tot_w ln_* psi*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Bilateral trade costs: Constrained
* Importer-time FEs    : Fully flexible
local model cons_flex 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau)

	* Estimation
	gen ln_tau_w = ln_tau + ln(w)
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i, a(i j#t) offset(ln_tau_w)
	boot_store 										// store bootstrap replication coefficients

	* Housekeeping
	drop w *tot_w ln_* ln_tau*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Bilateral trade costs: Constrained
* Importer-time FEs    : Somewhat constrained
local model cons_mid 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_*_j ln_tau)

	* Estimation
	gen ln_tau_w = ln_tau + ln(w)
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i ln_E_j ln_IMR_j, a(i t) offset(ln_tau_w)
	boot_store 										// store bootstrap replication coefficients

	* Housekeeping
	drop w *tot_w ln_* ln_tau*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Baseline model
* Bilateral trade costs: Constrained
* Importer-time FEs    : Constrained
local model baseline 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)

	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i, offset(ln_tau_psi_jt_w) a(i t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Baseline model with different IVs for OMR
frame change default 								// change to default dataset
merge 1:1 ij t using "$temp/stage1_brep0.dta", nogen keepusing(ln_tau ln_OMR_i)
gen ln_exports_tot = ln(exports_tot)
run "$code/[2.0_sub] construct_IV.do" 				// run do file to construct IVs
drop ln_* 											// housekeeping

capture drop t_* i_*
quietly tabulate t, generate(t_)
quietly tabulate i, generate(i_)
drop *_1 											// drop base year and exporter dummies (multi-collinearity)
frame copy default boot0, replace 					// replace frame to now include IVs 

capture program drop IV_boot_bayes
program IV_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)

	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	#delimit ;
	gmm (exports_tot_w - exp({xb: t_* i_*} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w)), 
		instruments(ln_A_i ln_L_i ln_K_i $IV t_* i_*) from(bA 0.2 bL 0.7 bK 0.3 bOMR -0.8) wmatrix(cluster ij) vce(cluster ij)
		deriv(/xb 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w) 		) 
		deriv(/bA 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w)*ln_A_i) 
		deriv(/bL 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w)*ln_L_i) 
		deriv(/bK 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w)*ln_K_i) 
		deriv(/bOMR = -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt_w)*ln_OMR_i) ;
	#delimit cr
	* Note: identical results but faster than the ivpoissson command below (because it uses analytical derivatives)
	* ivpoisson gmm exports_tot_w i.i i.t ln_A_i ln_L_i ln_K_i (ln_OMR_i = IV_ln_`iv'_`w'_i), offset(ln_tau_psi_jt_w) nocons

	* Store bootstrap replication coefficients
	boot_store
	
	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap for each IV
foreach iv in OMR OMR_feyrer tau_feyrer { 			// for different ways to construct the instrument
* 1) IV calculated from the system of MRs with base year weights
* 2) IV calculated from the system of MRs with base year weights using an estimated trade cost vector (tau) based on Feyrer (2019)
* 3) IV calculated as a base year weighted sum of the estimated trade cost vector (tau) based on Feyrer (2019)
	
	foreach w in EMP pop { 							// for different base year weights
		* i)  with employment base year weights
		* ii) with population base year weights
		local model IV_`iv'_`w' 					// name of estimation (also used to save results)
		global IV IV_ln_`iv'_`w'_i 					// name of instrument used in gmm

		* Run program for bootstrap
		global b = 0 								// start count indicator for bootstrap replication; 0 for estimates with original sample
		bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): IV_boot_bayes
		estimates save "$output_est/`model'_boot_bayes", replace 	
	}
}

* Housekeeping 
drop IV_* t_* i_*
frame copy default boot0, replace 					// replace frame to exclude IVs 


*-------------------------------------------------------------------------------
* Baseline model with exports corrected for the estimated error term in stage 1
local model baseline_hat 							// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *hat_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	ppmlhdfe exports_tot_hat_w ln_A_i ln_L_i ln_K_i ln_OMR_i, offset(ln_tau_psi_jt_w) a(i t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *hat_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Baseline model with exports corrected for all estimates in stage 1 (only varies at i,t level)
local model baseline_it 							// name of estimation (also used to save results)
frame copy default temp 							// create & copy current data to a temporary frame
frame change temp 									// change to temporary frame
keep if i == j

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *hat_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	gen exports_tot_tilde_w = exp(ln_exports_tot_hat_w - ln_tau_psi_jt)
	ppmlhdfe exports_tot_tilde_w ln_A_i ln_L_i ln_K_i ln_OMR_i if i == j, exposure(w) a(i t)
		
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *hat_w ln_* *tilde_w
	frame change temp 								// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 

frame change default 								// change back to default frame
frame drop temp 									// drop temporary frame


*-------------------------------------------------------------------------------
* Baseline model with alternative labour input measure (COMP "SEA2016 Compensation of employees (in millions of USD)")
local model L_other 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	replace ln_L_i = ln(COMP)
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i, offset(ln_tau_psi_jt_w) a(i t)
	replace ln_L_i = ln(LAB)

	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Baseline model with alternative labour input measure (COMP "SEA2016 Compensation of employees (in millions of USD)")
local model K_other 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	replace ln_K_i = ln(CAP)
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i, offset(ln_tau_psi_jt_w) a(i t)
	replace ln_K_i = ln(K)

	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace 


*-------------------------------------------------------------------------------
* Baseline model with constrained parameters and CRS
local model constrained_CRS 						// name of estimation (also used to save results)

capture drop t_* i_*
quietly tabulate t, generate(t_)
quietly tabulate i, generate(i_)
drop *_1 											// drop base year and exporter dummies (multi-collinearity)
frame copy default boot0, replace 					// replace frame to now include IVs 

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	#delimit ;
	gmm (exports_tot_w - exp({b0} + {xb: t_* i_*} - {a}*(ln_A_i + (1-{bg})*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)), 
		instruments(/* ln_A_i */ ln_L_i ln_K_i ln_OMR_i t_* i_*) from(b0 0  bg 0.3  a -0.8) wmatrix(cluster ij) vce(cluster ij)
		deriv(/xb = -1*exp({b0} + {xb:} - {a}*(ln_A_i + (1-{bg})*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w))
		deriv(/b0 = -1*exp({b0} + {xb:} - {a}*(ln_A_i + (1-{bg})*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w))
		deriv(/bg = -1*exp({b0} + {xb:} - {a}*(ln_A_i + (1-{bg})*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)*{a}*(ln_L_i-ln_K_i))
		deriv(/a  = -1*exp({b0} + {xb:} - {a}*(ln_A_i + (1-{bg})*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)*(-ln_A_i - (1-{bg})*ln_L_i - {bg}*ln_K_i + ln_OMR_i)) ;
	#delimit cr

	* Store bootstrap replication coefficients
	boot_store
	
	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes

* Back out sigma and test for CRS
estadd scalar CRS_chi2 = .
estadd scalar CRS_p = .
noisily nlcom 1 / (1 + _b[a:_cons]) 				// sigma
estimates save "$output_est/`model'_boot_bayes", replace 

* Housekeeping 
drop t_* i_*
frame copy default boot0, replace 					// replace frame to exclude IVs 


*-------------------------------------------------------------------------------
* Baseline model with constrained parameters and no CRS
local model constrained_noCRS 						// name of estimation (also used to save results)

capture drop t_* i_*
quietly tabulate t, generate(t_)
quietly tabulate i, generate(i_)
drop *_1 											// drop base year and exporter dummies (multi-collinearity)
frame copy default boot0, replace 					// replace frame to now include IVs 

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *tot_w ln_*_i ln_tau_psi_jt)
	
	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	#delimit ;
	gmm (exports_tot_w - exp({b0} + {xb: t_* i_*} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)), 
		instruments(/* ln_A_i */ ln_L_i ln_K_i ln_OMR_i t_* i_*) from(b0 0  bg 0.3  bL 0.7  a -0.7) wmatrix(cluster ij) vce(cluster ij)
		deriv(/b0 = -1*exp({b0} + {xb:} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w))
		deriv(/xb = -1*exp({b0} + {xb:} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w))
		deriv(/bL = -1*exp({b0} + {xb:} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)*-{a}*ln_L_i)
		deriv(/bg = -1*exp({b0} + {xb:} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)*-{a}*ln_K_i)
		deriv(/a  = -1*exp({b0} + {xb:} - {a}*(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) + ln_tau_psi_jt_w)*-(ln_A_i + {bL}*ln_L_i + {bg}*ln_K_i - ln_OMR_i) ) ;
	#delimit cr

	* Store bootstrap replication coefficients
	boot_store
	
	* Housekeeping 
	drop w *_tot_w ln_* 
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes

* Back out sigma and test for CRS
noisily test /bg + /bL = 1
estadd scalar CRS_chi2 = r(chi2)
estadd scalar CRS_p = r(p)
noisily lincom /bg + /bL - 1
noisily lincom /bg + /bL
noisily nlcom 1 / (1 + _b[a:_cons]) 				// sigma
estimates save "$output_est/`model'_boot_bayes", replace

* CRS
noisily margins, expression(_b[bg:_cons] + _b[bL:_cons]) post
estimates save "$output_est/`model'_crs_boot_bayes", replace

* Housekeeping 
drop t_* i_*
frame copy default boot0, replace 					// replace frame to exclude IVs 


*-------------------------------------------------------------------------------
* Baseline model under an AR1 process for productivity (assume iid productivity shock)
local model AR1 									// name of estimation (also used to save results)
frame copy default temp 							// create & copy current data to a temporary frame
frame change temp 									// change to temporary frame

capture drop t_* i_*
quietly tabulate t, generate(t_)
quietly tabulate i, generate(i_)
drop *_1 t_2 										// drop base year and exporter dummies (multi-collinearity)

frame copy temp boot0, replace 						// replace frame to now include dummies constructed as variables
xtset ij t
keep if i == j & !missing(L.exports_tot)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/stage1_brep$b.dta", nogen keepusing(w *hat_w ln_*_i ln_tau_psi_jt)
	
	* Create relevant variables
	gen ln_exports_tot_tilde_w = ln_exports_tot_hat_w - ln_tau_psi_jt
	gen exports_tot_tilde_w = exp(ln_exports_tot_tilde_w)
	gen ln_exports_tot_tilde = ln_exports_tot_tilde_w - ln(w)
	gen ln_w = ln(w)

	* Create lags (makes gmm below faster instead of creating lags directly in gmm as L.)
	xtset ij t
	foreach var in L_i K_i OMR_i exports_tot_tilde_w exports_tot_tilde w {
		gen L1_ln_`var' = L1.ln_`var'
	}

	* Estimation
	#delimit ;
	gmm (exports_tot_tilde_w - exp({b0} + {xb: t_* i_*} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
		 + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))) 
		if !missing(L1_ln_exports_tot_tilde) & i == j, from(b0 0 bL 0.7 bK 0.3 bOMR -0.8 rho 0.8) 
		instruments(ln_L_i ln_K_i ln_OMR_i L1_ln_exports_tot_tilde L1_ln_L_i L1_ln_K_i t_* i_*)
		deriv(/b0 	= -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))) 
		deriv(/xb 	= -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))) 
		deriv(/bL 	= -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))*(ln_L_i - {rho}*L1_ln_L_i)) 
		deriv(/bK 	= -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))*(ln_K_i - {rho}*L1_ln_K_i)) 
		deriv(/bOMR = -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))*(ln_OMR_i - {rho}*L1_ln_OMR_i)) 
		deriv(/rho 	= -1*exp({b0} + {xb:} + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_w
					  + {rho}*(L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i))*
							  (L1_ln_exports_tot_tilde - {bL}*L1_ln_L_i - {bK}*L1_ln_K_i - {bOMR}*L1_ln_OMR_i)) ;
	#delimit cr

	* Store bootstrap replication coefficients
	boot_store
	
	* Housekeeping 
	drop w *hat_w ln_* L1_* *tilde*
	frame change temp 								// change to default dataset
	global b = $b + 1 								// update count indicator

end

* Run program for bootstrap and store estimates
global b = 0 										// start count indicator for bootstrap replication; 0 for estimates with original sample
bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): `model'_boot_bayes
estimates save "$output_est/`model'_boot_bayes", replace

* Housekeeping 
drop t_* i_*
frame change default 								// change back to default frame
frame copy default boot0, replace 					// replace frame to exclude IVs 
frame drop temp 									// drop temporary frame


*-------------------------------------------------------------------------------
* General housekeeping
shell erase "$temp\stage1_brep*.dta"
clear frames
