version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   title  : Perform a test for weak instruments in linear instrumental variables
			regression that is robust to heteroscedasticity, autocorrelation, 
			and clustering by Montiel Olea and Pflueger (2013) presernted in 
			bottom row of Table 2 (columns 2-7).
   source : Regression results, 
   input  : $temp/sample.dta
   output : $output_est/XXX.ster
			$output_est/XXX.dta
			where XXX refers to the name of the respective file.
*/
*-------------------------------------------------------------------------------


*-------------------------------------------------------------------------------
use "$temp/sample.dta", clear

* Exporter, importer, year and (assymetric) pair groups
gegen i  = group(exporter)
gegen j  = group(importer)
gegen t  = group(year)
gegen ij = group(exporter importer)

* Symmetric pair groups
gen first  = cond(i < j, i, j)
gen second = cond(i < j, j, i)
gegen ij_symm = group(first second)
tabulate exporter importer if ij_symm == 1 			// check: group = 1 is domestic pair AUS-AUS
replace ij_symm = 1 if i == j 						// treat domestic pairs the same
drop first second

* Construct border dummies 
gen brdr = (exporter != importer)
label var brdr "dummy = 1 for international trade, i.e. i==j, and 0 for intranational trade"


*-------------------------------------------------------------------------------
* Stage 1: Run standard gravity and compute MR terms & other relevant variables
*-------------------------------------------------------------------------------
ppmlhdfe exports_tot rta_ml eu wto 1.brdr#i(3/15)bn.t, a(phi_it = i#t  psi_jt = j#t  miu_ij = ij_symm##c.t, savefe) d(fe) cluster(ij)
estimates save "$output_est/stage1", replace 		// save results in .ster file and call back any time for constructing result tables

* Predictions
predict exports_tot_hat, mu 						// expected trade flow value, i.e. fitted values
predict xb, xb 										// linear prediction: includes constant and excludes FEs
replace xb = xb - _b[_cons] 						// linear prediction: excludes constant and FEs
rename miu_ijSlope1 miu_ij_trend 					// symmetric pair-specific trade cost time trends
gen d_brdr = xb - _b[rta_ml] * rta_ml - _b[eu] * eu - _b[wto] * wto // border-time FEs

* Checks
gen res = exports_tot / exports_tot_hat
summarize exports_tot* 								// actual and predicted trade should have the same mean (up to rounding error)
summarize res 										// residuals should have a mean of ~ 1
drop res fe

* Multilateral resistances
* (i) normalize to get rid of the constant (absorb into the symmetric pair FE)
/* Note: the computed constant in reghdfe is a nuisance term that we normalise 
   to zero i.e. regressions without constant.
   - To "normalize" the constant to zero, we subtract _b[_cons] from each 
	 observation. For all observations, this will zero out _b[_cons].
   - Recall exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
   - Thus, if we subtract _b[_cons] from _b[_cons], we must add _b[_cons]
	 to the fixed effects. We do this by adding it to the symmetric pair FE.
	 (it does not really matter in which FE you absorb it).
*/
replace miu_ij = miu_ij + _b[_cons]

* (ii) normalize symmetric pair-specific trade costs (trends) by internal symmetric pair-specific trade costs (trends)
/* Note: the border-time dummies are already defined wrt. to domestic trade and
   have selected the base dummies to be dropped in the regression
*/
gen todrop = miu_ij if i == j
gen todrop2 = miu_ij_trend if i == j
gegen miu_ii = firstnm(todrop), by(i) 				// (logged) internal symmetric pair-specific trade costs for exporters
gegen miu_jj = firstnm(todrop), by(j) 				// (logged) internal symmetric pair-specific trade costs for importers
gegen miu_ii_trend = firstnm(todrop2), by(i) 		// (logged) internal symmetric pair-specific trade cost trends for exporters
gegen miu_jj_trend = firstnm(todrop2), by(j) 		// (logged) internal symmetric pair-specific trade cost trends for importers
drop todrop*

/*
* Check
bys t i (j): egen miu_ii2 = sum(miu_ij * (i == j))
bys t j (i): egen miu_jj2 = sum(miu_ij * (i == j))
bys t i (j): egen miu_ii2_trend = sum(miu_ij_trend * (i == j))
bys t j (i): egen miu_jj2_trend = sum(miu_ij_trend * (i == j))
assert(miu_ii == miu_ii2) & (miu_jj == miu_jj2) & (miu_ii_trend == miu_ii2_trend) & (miu_jj_trend == miu_jj2_trend)
*/

/* Note: we have computed (logged) internal symmetric pair-specific trade costs 
   (miu_ij) for exporters (miu_ii) and importers (miu_jj).
   - To "normalize" miu_ij to zero, we subtract miu_ii/2 + miu_jj/2 from each 
	 miu_ij. For i=j, this will zero out miu_ij.
   - Recall, exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
  	 - Thus, if we subtract miu_ii/2 for each observation where i is the exporter,
	   we must add miu_ii/2 to the phi_it's for that exporter.
	 - Likewise, if we subtract miu_jj/2 from each observation where j is the 
	   importer, we must ADD miu_jj/2 to the psi_jt's for that importer. 
   - This 50-50 split of the fixed effects for the normalization of miu_ij is not 
	 the only possibility. Other allocations could be chosen, e.g. 100-0, 30-70,
	 which should give the same results.
   - To normalise symmetric pair-specific trade cost trends (miu_ij_trend) to 0
	 for internal trade, we follow the same steps from above.
*/

replace miu_ij = miu_ij - miu_ii / 2 - miu_jj / 2 
replace miu_ij_trend = miu_ij_trend*t - (miu_ii_trend*t) / 2 - (miu_jj_trend*t) / 2

replace phi_it = phi_it + miu_ii / 2 + (miu_ii_trend*t) / 2
replace psi_jt = psi_jt + miu_jj / 2 + (miu_jj_trend*t) / 2
capture drop miu_ii* miu_jj*

summarize miu_ij* d_brdr if i == j 					// check: should be zero for internal trade (equivalent to dropping dummies for internal trade in a regression without a constant)
* Note: d_brdr is already normalised; base groups directly dropped in regression

* (iii) solve the system of MRs (set the reference country's IMR to 1)
/* Note: set importer USA as reference country, i.e. as if you drop the importer
   dummy for USA (for all years) in a regression without a constant and then do
   the typical normalization for solving the system of MRs.
*/

* Gross output and expenditure (logged)
gegen Y_i = sum(exports_tot), by(i t) 				// gross output at exporter-time level
gegen E_j = sum(exports_tot), by(j t) 				// expenditure at importer-time level
gen ln_Y_i = ln(Y_i)
gen ln_E_j = ln(E_j)

local cref USA 										// choose reference country
gegen E_j_ref = sum(exports_tot) if importer == "`cref'", by(t) // expenditure at importer-reference-country-time level
gegen E_j_ref = firstnm(E_j_ref), by(t) replace

gen psi_jt_ref = psi_jt if importer == "`cref'"
gegen psi_jt_ref = firstnm(psi_jt_ref), by(t) replace

replace phi_it = phi_it + psi_jt_ref - ln(E_j_ref)
replace psi_jt = psi_jt - psi_jt_ref + ln(E_j_ref)
/* Note: this is the typical normalization for solving the system of MRs, i.e.
   get rid of the constant and set `cref' as the reference country.
*/

* Check: should return 1's for the FEs and zero for the constant
ppmlhdfe exports_tot rta_ml eu wto 1.brdr#i(3/15)bn.t phi_it psi_jt miu_ij miu_ij_trend 
ppmlhdfe exports_tot rta_ml eu wto d_brdr phi_it psi_jt miu_ij miu_ij_trend 

* Outward and inward multilateral resistances (MRs in logs)
gen ln_OMR_i = ln_Y_i - phi_it
gen ln_IMR_j = ln_E_j - psi_jt

* Check: reference country IMR should be equal to 1 and ln_IMR equal to 0
noisily summarize ln_IMR_j if importer == "`cref'"

* Bilateral trade cost vector (logged)
gen ln_tau = xb + miu_ij + miu_ij_trend 			// include relevant FEs to the linear prediction vector (xb)

* Relevant constrained importer-time FEs & bilateral trade costs
gen ln_tau_psi_jt = ln_tau + psi_jt

* Production function variables and trade in logs
gen ln_A_i = ln(ctfp)
gen ln_L_i = ln(LAB)
gen ln_K_i = ln(K)
gen ln_exports_tot = ln(exports_tot)
gen ln_exports_tot_hat = ln(exports_tot_hat)

* Housekeeping
drop xb Y_i E_j *_ref miu* d_brdr


*-------------------------------------------------------------------------------
* Stage 2: Weak IV test a la Montiel Olea and Pflueger (2013)
*-------------------------------------------------------------------------------
* Baseline model in logs with different IVs for OMR
run "$code/[2.0_sub] construct_IV.do" 				// run do file to construct IVs

capture drop t_* i_*
quietly tabulate t, generate(t_)
quietly tabulate i, generate(i_)
drop *_1 											// drop base year and exporter dummies (multi-collinearity)

foreach iv in OMR OMR_feyrer tau_feyrer { 			// for different ways to construct the instrument
* 1) IV calculated from the system of MRs with base year weights
* 2) IV calculated from the system of MRs with base year weights using an estimated trade cost vector (tau) based on Feyrer (2019)
* 3) IV calculated as a base year weighted sum of the estimated trade cost vector (tau) based on Feyrer (2019)
	
	foreach w in EMP pop { 							// for different base year weights
		* i)  with employment base year weights
		* ii) with population base year weights
	
		* Heuristic indication of IV strength (there is no formal first stage)
		ivreg2 ln_exports_tot ln_A_i ln_L_i ln_K_i i.i i.t ln_tau_psi_jt (ln_OMR_i = IV_ln_`iv'_`w'_i), first cluster(ij)
		weakivtest 									// Montiel-Pflueger (2012) effective first-stage F statistic robust weak instrument test
		estadd scalar F_eff = r(F_eff) 				// store effective first-stage F statistic: for k = 1 exactly identified, gives the same F statistic as the Kleibergen-Paap Wald rk F statistic e(rkf)
		estimates save "$output_est/IV_`iv'_`w'_Ftest.ster", replace

		/*
		* Weak-IV robust inference for Just-Identified Models: The Anderson-Rubin Test
		  Anderson and Rubin (1949) propose a test of structural parameters (AR test) 
		  that turns out to be robust to weak instruments.
		  the Anderson-Rubin test is not a test for weak instruments, but a weak 
		  instrument-robust test of H0: beta = 0 (i.e. that β is not identified)
		  if F > 1- then we reject he null that β is totally unidentified. 
		  ivreg2 performs the Anderson-Rubin (AR) test for the null H0: b = 0 
		  - Anderson-Rubin Wald test F statistic 	e(arf)  
		  - Anderson-Rubin Wald test p-value 		e(arfp) 
		
		  Anderson and Rubin (1949)’s test largely avoids the problems that plague the
		  t-test. AR has correct size regardless of instrument strength. Hence, it is 
		  widely recommended by theorists for use in just-identified models with weak
		  instruments. Furthermore, it is the most powerful unbiased test in the single
		  instrument case, and it does not sacrifice power to the t-test when instruments
		  are strong. Importantly, we show the AR test is far less susceptible to the 
		  power asymmetry that afflicts the t-test. In particular, AR has far better 
		  power to detect negative effects when the OLS bias is positive. Thus, we 
		  advise discarding the 2SLS t-test altogether, and using AR even with strong 
		  instruments.	
		
		* Weak instrument tests
		  Conduct valid weak instrument tests based on the Montiel-Pflueger (2013) 
		  effective first-stage F statistic robust weak instrument test.
		  For k = 1, one can use the effective F-statistic reported by weakivtest, 
		  or the KleibergenPaap statistic reported by ivreg2,	along with the Stock and
		  Yogo (2005) critical values to test for size distortions.
		  Rule-of-thumb approach: “Weak” if FEff < 10
		  Their test rejects when the effective F-statistic exceeds a critical value.
		  
		* References
		  Montiel Olea, J.L. and C.E. Pflueger (2013). “A Robust Test for Weak Instruments,” Journal of Business and Economic Statistics 31, 358-369.
		  Andrews, I., Stock, J. H., & Sun, L. (2019). Weak instruments in instrumental variables regression: Theory and practice. Annual Review of Economics, 11(1), 727-753.
	    */
		
		* Estimation
		#delimit ;
		gmm (exports_tot - exp({xb: t_* i_*} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt)), 
			instruments(ln_A_i ln_L_i ln_K_i IV_ln_`iv'_`w'_i t_* i_*) from(bA 0.2 bL 0.7 bK 0.3 bOMR -0.8) wmatrix(cluster ij) vce(cluster ij)
			deriv(/xb 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt) 	  ) 
			deriv(/bA 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt)*ln_A_i) 
			deriv(/bL 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt)*ln_L_i) 
			deriv(/bK 	= -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt)*ln_K_i) 
			deriv(/bOMR = -1*exp({xb:} + {bA}*ln_A_i + {bL}*ln_L_i + {bK}*ln_K_i + {bOMR}*ln_OMR_i + ln_tau_psi_jt)*ln_OMR_i) ;
		#delimit cr
		* Note: identical results but faster than the ivpoissson command below (because it uses analytical derivatives)
		* ivpoisson gmm exports_tot i.i i.t ln_A_i ln_L_i ln_K_i (ln_OMR_i = IV_ln_`iv'_`w'_i), offset(ln_tau_psi_jt) nocons
		estimates save "$output_est/IV_`iv'_`w'.ster", replace	
	}
}
drop IV_* t_* i_*
