version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   title  : Construct instrumental variables (IV) for IV regressions stage-2
			regressions in "[2.0] estimations_boot_bayes.do".
   source : IVs
   input  : data and computed variables after stage-1 regressions performed in 
			"[2.0] estimations_boot_bayes.do". 
   output : add computed IVs in the current dataset
*/
*-------------------------------------------------------------------------------


*------Estimation of alternative trade cost vector based on Feyrer (2019)-------
gen ln_dist = ln(dist)

ppmlhdfe exports_tot ln_dist c.ln_dist#i.t, a(ij t) d(fe)

* Construct bilateral trade cost vector a la Feyrer (2019)
predict ln_tau_feyrer, xb 							// linear prediction: includes constant and excludes FEs
replace ln_tau_feyrer = ln_tau_feyrer - _b[_cons] 	// linear prediction: excludes constant and excludes FEs, note: the constant is a nuisance parameter that is part of the FEs

corr ln_exports_tot ln_tau_feyrer


*-------------------------------------------------------------------------------
* Set up system of nonlinear equations to construct IVs for MRs (in Mata)
*-------------------------------------------------------------------------------
clear mata
mata:
	void function MR_IV(real colvector from, real colvector values)
	{
		// Declarations
		external real matrix T
		external real scalar N
		external real vector w_var
		real scalar 		 i
		real colvector 		 w

		// System of nonlinear equations for MRs
		w = w_var :/ sum(w_var) 										// column vector with weights fixed at base year
		values[1::N] = rowsum(T :/ from[N + 1::2*N]' :* w') 			// OMR sum across rows (importers)
		values[N + 1::2*N - 1] = colsum(T[|(1, 1) \ (N, N-1) |] :/ from[1::N] :* w )' // IMR sum across columns (exporters)

		// Set IMR for US to 1 (US is last country in the list)
		values[2*N] = from[2*N] = 1
	}
end


*-------------------------------------------------------------------------------
* Load data & solve the system of equations to construct IVs for MRs (per year)
*-------------------------------------------------------------------------------
sort year exporter importer
gen byear = (year == 2000 & i == j) 									// 0|1 identifier, where: 1 for base year and domestic trade (& 0 otherwise)

foreach tau in ln_tau ln_tau_feyrer { 									// for different estimates of trade cost vectors
	foreach w in EMP pop {												// for different base year weights

		quietly glevelsof year, local(periods) 
		foreach t of local periods { 									// for each year
			capture drop touse*
			gen touse = (year == `t') 									// 0|1 identifier, where: 1 for relevant year (& 0 for all other years)
			
			mata {
				// Load data
				touse = st_data(., "touse")
				byear = st_data(., "byear")											
				tau   = exp(st_data(., "`tau'")[selectindex(touse), .]) // estimated (1-sigma) Power Transformations of trade costs (from stage 1)
				w_var = st_data(., "`w'")[selectindex(byear), .] 		// column vector with the variable for weights (fixed at base year)
				N 	  = sqrt(rows(tau)) 								// number of countries
				
				// Reshape exponentiated (1-sigma) bilateral trade cost vector (tau) to a NxN matrix (T) where exporters are in rows and importers in columns
				T = J(N, N, .)
				for(i = 1; i <= N; i = i + 1) {
					T[i, .] = tau[((i - 1)*N + 1)::i*N]' 				// call a column vector of observations for each exporter across all importers and reshape to long format 
				}
				_diag(T, 0) 											// exclude diagonal elements from summation
				
				// Set-up numerical method & execute 
				S = solvenl_init()
				solvenl_init_evaluator(S, &MR_IV()) 					// specify the function to be called to evaluate F(x) (defined above in MR_IV())
				solvenl_init_type(S, "fixedpoint") 						// specify whether to find a fixed point or a zero of the function
				solvenl_init_technique(S, "dampedgaussseidel") 			// specify the solver technique to use
				solvenl_init_numeq(S, 2*N) 								// set the number of equations in the system to 2*N
				solvenl_init_startingvals(S, J(2*N, 1, 1)) 				// set the initial values for the solver to 1
				solvenl_init_conv_maxiter(S, 1000) 						// specifies the maximum number of iterations to perform (default is 300, choose any number between 0 and 16,000)	
				solvenl_init_iter_log(S, "off") 						// specify whether an iteration log should or should not be displayed
				x = solvenl_solve(S) 									// invoke the solver and return the resulting solution to the vector x
				if (solvenl_result_converged(S) == 0) printf("No convergence") 	// returns 1 if the solver found a solution to the problem and 0 otherwise

				// Append the MRs across all years
				t = st_local("t")
				if (t == "2000") {
					OMR_IV = x[1::N]
					IMR_IV = x[N + 1::2*N]
				}
				else {
					OMR_IV = OMR_IV \ x[1::N]
					IMR_IV = IMR_IV \ x[N + 1::2*N]
				}
			}
		}

		* Expand the log of IV MRs across all trade partners and store in Stata - recall that MRs are (1-sigma) power transformations
		* i) OMR
		quietly mata {
			ln_OMR_IV = ln(OMR_IV # J(N, 1, 1))
			st_addvar("double", "IV_ln_OMR_new_i")
			st_store(., "IV_ln_OMR_new_i", ln_OMR_IV)
		}

		* ii) IMR
		sort year importer exporter
		quietly mata {
			ln_IMR_IV = ln(IMR_IV # J(N, 1, 1))
			st_addvar("double", "IV_ln_IMR_new_j")
			st_store(., "IV_ln_IMR_new_j", ln_IMR_IV)
		}

		if "`tau'" == "ln_tau" 				rename *new* *`w'* 
		else if "`tau'" == "ln_tau_feyrer" 	rename *new* *feyrer_`w'*

		sort year exporter importer
	}
}

* Construct additional IVs for OMRs similar to Feyrer (2019), 
* i.e. weighted sum of estimated tau (excluding domestic trade costs)
gen tau_feyrer = exp(ln_tau_feyrer)
replace tau_feyrer = 0 if i == j 					// exclude domestic trade costs from summation

foreach w in EMP pop {								// for different base year weights
	capture drop w tot
	gen w = `w' if byear
	gegen tot = sum(w) if i == j, by(year)
	replace w = w / tot
	gegen w = firstnm(w), by(j) replace
	bys i t: gegen IV_ln_tau_feyrer_`w'_i = sum(w*tau_feyrer), replace
	replace IV_ln_tau_feyrer_`w'_i = ln(IV_ln_tau_feyrer_`w'_i)
}

* Check
corr ln_OMR_i IV_* 

* Housekeeping
drop fe byear touse w tot ln_dist ln_tau_feyrer tau_feyrer
drop *IV*IMR* 										// drop instruments for IMRs since we do not need them.
