version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   title  : Estimate & store results presented in manuscript Table 3; & online 
			appendix Tables D.1-D.3.
   source : Regression results, 
   input  : $temp/sample.dta
   output : $output_est/XXX.ster
			$output_est/XXX.dta
			where XXX refers to the name of the respective file.
*/
*-------------------------------------------------------------------------------


*--------------------------Define macros for bootstrap--------------------------
global seed 	1658203945 							// set random-# seed for replicability of results
global B		100 								// # of bootstrap replications


*------------------------------Define programmes--------------------------------
* Set program to store bootstrap replication coefficients
capture program drop boot_store
program define boot_store

	* Store bootstrap replication coefficients (excluding dummy variables)
	matrix b = e(b) 								// estimated parameters
	
	** Post Total R&D effect
	capture summarize b_ln_var_itbrdr
	capture scalar b_int = r(mean)
	capture scalar b_int = _b[ln_var_itbrdr]
	matrix tot = _b[ln_var_it] + b_int 				// calculate and store total effect
	matrix colnames tot = tot 						// rename column names to avoid duplicates
	matrix b = b, tot 								// add total effect to the rest of the results

	*---------------------------------------------------------------------------
	* Post bootstrap replication results
	ereturn post b
	
	** Post Total R&D effect
	estadd scalar tot = _b[ln_var_it] + b_int 		// total effect of country specific variable

end


*-------------------------------------------------------------------------------
* Program to bootstrap stage 1 standard gravity estimating equation
*-------------------------------------------------------------------------------
* Program to bootstrap 1st stage
* Implement Bayesian bootstrap (Rubin, 1981) also known as exchangeably weighted
* bootstrap scheme where we apply weighted regressions using weights drawn from 
* the exponential distribution generating strictly positive, non-integer weights
capture program drop rnd_stage1_boot_bayes
program rnd_stage1_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates
	
	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	frlink 1:1 ij t, frame(boot_weights) 			// create linkages to frame with bootstrap replication weights
	frget w = bw_$b, from(boot_weights) 			// copy relevant bootstrap weight from the linked frame and rename it to w
	gen exports_tot_w = exports_tot * w 			// adjust the dependent variable for weighted ppml regression below
	
	* Stage 1: Standard gravity
	ppmlhdfe exports_tot_w rta_ml eu wto ln_var_itbrdr 1.brdr#i(3/15)bn.t, exposure(w) a(phi_it = i#t  psi_jt = j#t  miu_ij = ij_symm##c.t, savefe) d(fe)
	* Note: gives the same results as the command below, but faster
	// ppmlhdfe exports_tot rta_ml eu wto ln_var_itbrdr 1.brdr#i(3/15)bn.t [w = w], a(phi_it = i#t  psi_jt = j#t  miu_ij = ij_symm##c.t, savefe) d(fe) 	// note: all predictions do not include weights

	* Store bootstrap replication coefficients
	matrix b = e(b) 								// estimated parameters
	
	gen b_ln_var_itbrdr = _b[ln_var_itbrdr] 		// store to use to constuct totals in stage2

	* Predictions
	predict exports_tot_hat_w, mu 					// expected trade flow value, i.e. fitted values (includes weights)
	predict xb, xb 									// linear prediction: includes constant and weights, and excludes FEs
	replace xb = xb - _b[_cons] - ln(w)				// linear prediction: excludes constant, FEs and weights
	rename miu_ijSlope1 miu_ij_trend 				// symmetric pair-specific trade cost time trends
	gen d_brdr = xb - _b[rta_ml] * rta_ml - _b[eu] * eu - _b[wto] * wto - _b[ln_var_itbrdr] * ln_var_itbrdr // border-time FEs

	* Checks
	gen res = (exports_tot_w / exports_tot_hat_w) * w 
	summarize exports_tot* 							// actual and predicted trade should have the same mean (up to rounding error)
	summarize res 									// residuals should have a mean of ~ 1
	drop res fe

	* Multilateral resistances
	* (i) normalize to get rid of the constant (absorb into the symmetric pair FE)
	/* Note: the computed constant in reghdfe is a nuisance term that we normalise 
	   to zero i.e. regressions without constant.
	   - To "normalize" the constant to zero, we subtract _b[_cons] from each 
		 observation. For all observations, this will zero out _b[_cons].
	   - Recall exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
	   - Thus, if we subtract _b[_cons] from _b[_cons], we must add _b[_cons]
		 to the fixed effects. We do this by adding it to the symmetric pair FE.
		 (it does not really matter in which FE you absorb it).
	*/
	replace miu_ij = miu_ij + _b[_cons]

	* (ii) normalize symmetric pair-specific trade costs (trends) by internal symmetric pair-specific trade costs (trends)
	/* Note: the border-time dummies are already defined wrt. to domestic trade and
	   have selected the base dummies to be dropped in the regression
	*/
	gen todrop = miu_ij if i == j
	gen todrop2 = miu_ij_trend if i == j
	gegen miu_ii = firstnm(todrop), by(i) 			// (logged) internal symmetric pair-specific trade costs for exporters
	gegen miu_jj = firstnm(todrop), by(j) 			// (logged) internal symmetric pair-specific trade costs for importers
	gegen miu_ii_trend = firstnm(todrop2), by(i) 	// (logged) internal symmetric pair-specific trade cost trends for exporters
	gegen miu_jj_trend = firstnm(todrop2), by(j) 	// (logged) internal symmetric pair-specific trade cost trends for importers
	drop todrop*

	/* Note: we have computed (logged) internal symmetric pair-specific trade costs 
	   (miu_ij) for exporters (miu_ii) and importers (miu_jj).
	   - To "normalize" miu_ij to zero, we subtract miu_ii/2 + miu_jj/2 from each 
		 miu_ij. For i=j, this will zero out miu_ij.
	   - Recall, exports_tot_hat = exp(xb + _b[_cons] + phi_it + psi_jt + miu_ij + miu_ij_trend)
		 - Thus, if we subtract miu_ii/2 for each observation where i is the exporter,
		   we must add miu_ii/2 to the phi_it's for that exporter.
		 - Likewise, if we subtract miu_jj/2 from each observation where j is the 
		   importer, we must ADD miu_jj/2 to the psi_jt's for that importer. 
	   - This 50-50 split of the fixed effects for the normalization of miu_ij is not 
		 the only possibility. Other allocations could be chosen, e.g. 100-0, 30-70,
		 which should give the same results.
	   - To normalise symmetric pair-specific trade cost trends (miu_ij_trend) to 0
		 for internal trade, we follow the same steps from above.
	*/

	replace miu_ij = miu_ij - miu_ii / 2 - miu_jj / 2 
	replace miu_ij_trend = miu_ij_trend *t - (miu_ii_trend*t) / 2 - (miu_jj_trend*t) / 2

	replace phi_it = phi_it + miu_ii / 2 + (miu_ii_trend*t) / 2
	replace psi_jt = psi_jt + miu_jj / 2 + (miu_jj_trend*t) / 2
	capture drop miu_ii* miu_jj*

	summarize miu_ij* d_brdr if i == j 				// check: should be zero for internal trade (equivalent to dropping dummies for internal trade in a regression without a constant)
	* Note: d_brdr is already normalised; base groups directly dropped in regression

	* (iii) solve the system of MRs (set the reference country's IMR to 1)
	/* Note: set importer USA as reference country, i.e. as if you drop the importer
	   dummy for USA (for all years) in a regression without a constant and then do
	   the typical normalization for solving the system of MRs.	*/

	* Gross output and expenditure (logged)
	gegen Y_i = sum(exports_tot_w), by(i t) 		// gross output at exporter-time level
	gegen E_j = sum(exports_tot_w), by(j t) 		// expenditure at importer-time level
	gen ln_Y_i = ln(Y_i)
	gen ln_E_j = ln(E_j)

	local cref USA 									// choose reference country
	gegen E_j_ref = sum(exports_tot_w) if importer == "`cref'", by(t) // expenditure at importer-reference-country-time level
	gegen E_j_ref = firstnm(E_j_ref), by(t) replace

	gen psi_jt_ref = psi_jt if importer == "`cref'"
	gegen psi_jt_ref = firstnm(psi_jt_ref), by(t) replace

	replace phi_it = phi_it + psi_jt_ref - ln(E_j_ref)
	replace psi_jt = psi_jt - psi_jt_ref + ln(E_j_ref)
	/* Note: this is the typical normalization for solving the system of MRs, 
	   i.e. get rid of the constant and set `cref' as the reference country. */

	* Check: should return 1's for the FEs and zero for the constant
	ppmlhdfe exports_tot_w rta_ml eu wto ln_var_itbrdr 1.brdr#i(3/15)bn.t phi_it psi_jt miu_ij miu_ij_trend, exposure(w)
	ppmlhdfe exports_tot_w rta_ml eu wto ln_var_itbrdr d_brdr 			  phi_it psi_jt miu_ij miu_ij_trend, exposure(w)

	* Outward and inward multilateral resistances (MRs in logs)
	gen ln_OMR_i = ln_Y_i - phi_it
	gen ln_IMR_j = ln_E_j - psi_jt

	* Check: reference country IMR should be equal to 1 and ln_IMR equal to 0
	summarize ln_IMR_j if importer == "`cref'"

	* Bilateral trade cost vector (logged)
	gen ln_tau = xb + miu_ij + miu_ij_trend 		// include relevant FEs to the linear prediction vector (xb)

	* Relevant constrained importer-time FEs & bilateral trade costs
	gen ln_tau_psi_jt = ln_tau + psi_jt
	
	* Housekeeping
	drop xb *_ref miu* d_brdr *Y_i *_j psi* *hat_w *tau

	* Post bootstrap replication results from stage 1
	ereturn post b	

	preserve
		keep ij t w *tot_w ln_*_i b_ln_var_itbrdr ln_tau_psi_jt phi_it
		save "$temp/rnd_stage1_brep$b.dta", replace
	restore

	* Housekeeping 
	drop *_i *tot_* w boot_weights b_ln_var_itbrdr *tau* phi_it*

	frame change default 							// change to default dataset

	global b = $b + 1 								// update count indicator
end


*-------------------------------------------------------------------------------
* Programs to bootstrap stage 2 estimating equations
*-------------------------------------------------------------------------------
** Baseline model
local model rnd_baseline 							// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates
	tempname b_int 									// tempname for matrix where we store bootstrap estimates
	tempname tot 									// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/rnd_stage1_brep$b.dta", nogen

	* Production function variables and trade in logs
	gen ln_A_i = ln(ctfp)
	gen ln_L_i = ln(LAB)
	gen ln_K_i = ln(CAP)
	
	* Estimation
	gen ln_tau_psi_jt_w = ln_tau_psi_jt + ln(w) 
	ppmlhdfe exports_tot_w ln_A_i ln_L_i ln_K_i ln_OMR_i ln_var_it, offset(ln_tau_psi_jt_w) a(i t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_*_i ln_tau* b_ln_var* phi*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end

*-------------------------------------------------------------------------------
** Model using exporter-time FEs as left-hand side variable when:
* a) using linear regression (note: at the export-year dimension)
local model rnd_fe_reg 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates
	tempname b_int 									// tempname for matrix where we store bootstrap estimates
	tempname tot 									// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/rnd_stage1_brep$b.dta", nogen

	* Production function variables and trade in logs
	gen ln_A_i = ln(ctfp)
	gen ln_L_i = ln(LAB)
	gen ln_K_i = ln(CAP)
	
	* Estimation
	reghdfe phi_it ln_A_i ln_L_i ln_K_i ln_OMR_i ln_var_it if i == j [aw = w], a(i t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_*_i ln_tau* b_ln_var* phi*
	frame change temp 								// change to default dataset
	global b = $b + 1 								// update count indicator

end

*-------------------------------------------------------------------------------
** Model using exporter-time FEs as left-hand side variable when:
* b) using ppml (note: at the export-year dimension)
local model rnd_fe_ppml 							// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates
	tempname b_int 									// tempname for matrix where we store bootstrap estimates
	tempname tot 									// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/rnd_stage1_brep$b.dta", nogen

	* Production function variables and trade in logs
	gen ln_A_i = ln(ctfp)
	gen ln_L_i = ln(LAB)
	gen ln_K_i = ln(CAP)
	
	* Estimation
	gen PHI_it_w = exp(phi_it) * w
	ppmlhdfe PHI_it_w ln_A_i ln_L_i ln_K_i ln_OMR_i ln_var_it if i == j, exposure(w) a(i t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_*_i ln_tau* b_ln_var* phi* PHI_it_w
	frame change temp 								// change to default dataset
	global b = $b + 1 								// update count indicator

end

*-------------------------------------------------------------------------------
** Naive gravity variables, including remoteness index
local model rnd_naive 								// name of estimation (also used to save results)

capture program drop `model'_boot_bayes
program `model'_boot_bayes, eclass
	tempname b 										// tempname for matrix where we store bootstrap estimates
	tempname b_int 									// tempname for matrix where we store bootstrap estimates
	tempname tot 									// tempname for matrix where we store bootstrap estimates

	* Relevant data for each bootstrap replication
	frame change boot0 								// switch to the frame with the original data for every bootstrap replication
	merge 1:1 ij t using "$temp/rnd_stage1_brep$b.dta", nogen

	* Production function variables and trade in logs
	gen ln_A_i = ln(ctfp)
	gen ln_L_i = ln(LAB)
	gen ln_K_i = ln(CAP)
	
	* Naive gravity variables, including remoteness index
	gen gdp_i = cgdpo
	gen gdp_j = gdp_i if i == j
	gegen gdp_j = firstnm(gdp_j), by(j t) replace
	gegen ln_remote_i = mean(dist) [aweight = gdp_j], by(i t)
	replace ln_remote_i = ln(ln_remote_i)
	gen ln_gdp_i = ln(gdp_i)
	
	* Estimation
	ppmlhdfe exports_tot_w rta_ml eu wto ln_remote_i ln_gdp_i ln_var_itbrdr ln_var_it, exposure(w) a(j#t i ij_symm##c.t brdr#t)
	
	* Store bootstrap replication coefficients
	boot_store

	* Housekeeping 
	drop w *_tot_w ln_*_i ln_tau* b_ln_var* phi* gdp_* ln_remote_* ln_gdp_*
	frame change default 							// change to default dataset
	global b = $b + 1 								// update count indicator

end


*-------------------------------------------------------------------------------
* Run bootsrap replications for each type of R&D spending 
*-------------------------------------------------------------------------------

foreach var_it in G_PPP H_PPP B_PPP GV_PPP { 		// for different country-specific variables

	* Intuitive names for the country-specific variables to store results
	if 		"`var_it'" == "G_PPP"  local name RDtot // total R&D spending: gross domestic expenditure on R&D (GERD) in million US dollars, PPP converted in current prices
	else if "`var_it'" == "H_PPP"  local name RDhed // higher education R&D spending: higher education expenditure on R&D (HERD) in million US dollars, PPP converted in current prices
	else if "`var_it'" == "B_PPP"  local name RDbus // business R&D spending: business enterprise expenditure on R&D (BERD) in million US dollars, PPP converted in current prices
	else if "`var_it'" == "GV_PPP" local name RDgov // government R&D spending: government intramural expenditure on R&D (GVERD) in million US dollars, PPP converted in current prices

	clear frames
	use "$temp/sample.dta", clear
	set seed $seed 									// set random-# seed for replicability of results

	* Merge country-specific variables
	/* Note: no information on R&D spending for BRA, CYP, IDN, IND, MLT. Thus,
	   we drop these countries from both the importing and exporting side.*/
	merge m:1 exporter year using "$temp/oecd_msti.dta", nogen keep(master matched) keepusing(`var_it' POP)
	tabulate exporter if missing(`var_it')
	drop if inlist(importer, "BRA", "CYP", "IDN", "IND", "MLT")
	drop if inlist(exporter, "BRA", "CYP", "IDN", "IND", "MLT")

	* Exporter, importer, year and (assymetric) pair groups
	gegen i = group(exporter)
	gegen j = group(importer)
	gegen t = group(year)
	gegen ij = group(exporter importer)

	* Symmetric pair groups
	gen first  = cond(i < j, i, j)
	gen second = cond(i < j, j, i)
	gegen ij_symm = group(first second)
	tabulate exporter importer if ij_symm == 1 		// check: group = 1 is domestic pair AUS-AUS
	replace ij_symm = 1 if i == j 					// treat domestic pairs the same
	drop first second

	* Construct border dummies 
	gen brdr = (exporter != importer)
	label var brdr "dummy = 1 for international trade, i.e. i==j, and 0 for intranational trade"

	* Country-specific variables
	gen ln_var_it = ln(`var_it' / POP) 				// per capita
	gen ln_var_itbrdr = ln_var_it * brdr

	* Create & copy current data to new frame (call in each bootstrap replication)
	frame copy default boot0 

	* Bootstrap replication weights for Bayesian bootstrap (Rubin, 1981) also known
	* as exchangeably weighted bootstrap schemes
	gen bw_0 = 1 									// weight for original sample regressions
	exbsample $B, seed($seed) stub(bw_) cluster(ij) // continuous weights for bayesian sampling
	/* Note: draws from an exponential distribution with unit mean (alternatively 
	   draw from a Poisson distribution). Drawing from the exponential distribution
	   generates strictly positive, non-integer weights. Draws from the exponential 
	   distribution can be seen as continuous (smoothed) versions of Poisson draws. 
	   The advantage of exponential draws is the absence of zero weights: all observations
	   from the original data are kept in bootstrap resamples, albeit with possibly 
	   small weights. This can have practical computational advantages such as when
	   computing MR terms. In both cases, replication weights are, by default, scaled
	   to sum to the sample size N.
	   Observations from the same cluster all have the same weight and weights sum 
	   to the number of clusters.
	 */

	* Copy bootstrap replication weights to a new frame (call in each bootstrap replication)
	frame put ij t bw_*, into(boot_weights)
	drop bw_*

	*---------------------------------------------------------------------------
	* Stage 1: Standard gravity including marginal country-specific effects
	*---------------------------------------------------------------------------
	* Run program for bootstrap
	global b = 0 									// start count indicator for bootstrap replication; 0 for estimates with original sample
	bootstrap, saving("$output_est/`name'_stage1_breps_bayes",replace) reps($B) seed($seed): rnd_stage1_boot_bayes 
	estimates save "$output_est/`name'_stage1_boot_bayes", replace // save results in .ster file and call back any time for constructing result tables


	*---------------------------------------------------------------------------
	* Stage 2: Estimating equation
	*---------------------------------------------------------------------------
	** Baseline model
	local model `name'_baseline 					// name of estimation (also used to save results)
	global b = 0 									// start count indicator for bootstrap replication; 0 for estimates with original sample
	bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): rnd_baseline_boot_bayes
	estimates save "$output_est/`model'_boot_bayes", replace 

	*---------------------------------------------------------------------------
	** Model using exporter-time FEs as left-hand side variable when:
	* a) using linear regression (note: at the export-year dimension)
	local model `name'_fe_reg 						// name of estimation (also used to save results)
	frame copy default temp 						// create & copy current data to a temporary frame
	frame change temp 								// change to temporary frame
	keep if i == j 									// keep relevant sample

	* Run program for bootstrap
	global b = 0 									// start count indicator for bootstrap replication; 0 for estimates with original sample
	bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): rnd_fe_reg_boot_bayes
	estimates save "$output_est/`model'_boot_bayes", replace 

	* Housekeeping 
	frame change default 							// change back to default frame
	frame drop temp 								// drop temporary frame

	*---------------------------------------------------------------------------
	** Model using exporter-time FEs as left-hand side variable when:
	* b) using ppml (note: at the export-year dimension)
	local model `name'_fe_ppml 						// name of estimation (also used to save results)
	frame copy default temp 						// create & copy current data to a temporary frame
	frame change temp 								// change to temporary frame
	keep if i == j 									// keep relevant sample

	* Run program for bootstrap
	global b = 0 									// start count indicator for bootstrap replication; 0 for estimates with original sample
	bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): rnd_fe_ppml_boot_bayes
	estimates save "$output_est/`model'_boot_bayes", replace 

	* Housekeeping 
	frame change default 							// change back to the default frame
	frame drop temp 								// drop temporary frame	

	*---------------------------------------------------------------------------
	** Naive gravity variables, including remoteness index
	local model `name'_naive 						// name of estimation (also used to save results)
	global b = 0 									// start count indicator for bootstrap replication; 0 for estimates with original sample
	bootstrap, saving("$output_est/`model'_breps_bayes", replace) reps($B) seed($seed): rnd_naive_boot_bayes
	estimates save "$output_est/`model'_boot_bayes", replace 

}


*-------------------------------------------------------------------------------
* General housekeeping
shell erase "$temp\rnd_stage1_brep*.dta"
clear frames
