version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   title  : Export all Tables in manuscript and appendix in .tex and .log files
   source : Estimation results, 
   input  : $output_estimates/XXX.ster
   output : $output_tables/table_XXX.tex and $output_tables/_table_XXX.log
*/ 
*-------------------------------------------------------------------------------


*--------------Table 1 - Baseline results with country-level data---------------	
local table table_1 								// table name
local columns flex_flex flex_mid flex_cons cons_flex cons_mid baseline	// columns in table

foreach name of local columns {
	estimates use "$output_est/`name'_boot_bayes" 	// load estimation results
	estimates store `name' 							// store results to create columns below
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'.tex", replace stats(N, labels("Observations") fmt(%9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(ln_A_i 	"$\!ln(A_{it})\$" 
			   ln_L_i 	"$\!ln(L_{it})\$" 
			   ln_K_i 	"$\!ln(K_{it})\$"
			   rta_ml 	"$\!RTA_{ijt}\$" 
			   eu 		"$\!EU_{ijt}\$" 
			   wto 		"$\!WTO_{ijt}\$"
			   ln_OMR_i "$\!ln(\Pi_{it}^{1-\sigma})\$" 
			   ln_E_j 	"$\!ln(E_{jt})\$" 
			   ln_IMR_j "$\!ln(P_{jt}^{1-\sigma})\$")
		varlabels(, nolast elist("$\!ln(P_{jt}^{1-\sigma})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "{jt" "{j,t"  "{ijt"  "{ij,t"
				   "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})" 
				   "(P_{j,t}^{1-\sigma})"   "(\widehat{P_{j,t}^{1-\sigma}})") noomitted ;
#delimit cr

* Log file
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) ///
		stats(N, labels("Observations") fmt(%9.3g %9.0fc)) drop(_cons)
capture log close


*---------------Table 2 - Baseline results with IVs for OMR terms---------------
* Program to repost column labels below for AR1 process
capture prog drop replace_b
program replace_b, eclass
	ereturn repost b = b, rename
end

* Program to repost column labels below for standard errors from AR1 process
capture prog drop replace_se
program replace_se, eclass
	estadd matrix se, replace 
end

	
local table table_2 								// table name
local columns baseline IV_OMR_EMP IV_OMR_feyrer_EMP IV_tau_feyrer_EMP IV_OMR_pop IV_OMR_feyrer_pop IV_tau_feyrer_pop // columns in table

foreach name of local columns {
	estimates use "$output_est/`name'_boot_bayes" 	// load estimation results
	
	if "`name'" != "baseline" {
		* Store estimation results in matrix b and access all colnames
		mat b = e(b)
		local colnames: colfullnames b

		* Substitute particular string in colnames list
		local colnames : subinstr local colnames "bA:_cons" 	"ln_A_i", all
		local colnames : subinstr local colnames "bK:_cons" 	"ln_K_i", all
		local colnames : subinstr local colnames "bL:_cons" 	"ln_L_i", all
		local colnames : subinstr local colnames "bOMR:_cons" 	"ln_OMR_i", all

		* Rename matrix colnames with new local list and repost
		matrix colname b = `colnames'
		matrix colnames b = b:
		replace_b 									// repost column labels below for AR1 process
		
		* Update column labels for standard errors
		matrix se = e(se)
		matrix colnames se = `colnames'
		matrix colnames se = b:
		replace_se
	}
	estimates store `name' 							// store results to create columns below
	
	* Heuristic indication of IV strength (there is no formal first stage)
	if "`name'" != "baseline" {
		estimates use "$output_est/`name'_Ftest" 	// load estimation results
		estimates store `name'_Ftest 				// store results to create columns below
	}
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(ln_A_i 	"$\!ln(A_{it})\$" 
			   ln_L_i 	"$\!ln(L_{it})\$" 
			   ln_K_i 	"$\!ln(K_{it})\$"
			   ln_OMR_i "$\!ln(\Pi_{it}^{1-\sigma})\$")
		varlabels(, nolast elist("$\!ln(\Pi_{it}^{1-\sigma})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "{jt" "{j,t"  "{ijt"  "{ij,t"
				   "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})" "IV_" "") noomitted ;
#delimit cr

* Log file
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) /// 
		stats(N, labels("Observations") fmt(%9.3g %9.0fc)) drop(_cons) substitute("IV_" "   ")
capture log close


* Tex Table (first stage tests)
local columns baseline IV_OMR_EMP_Ftest IV_OMR_feyrer_EMP_Ftest IV_tau_feyrer_EMP_Ftest IV_OMR_pop_Ftest IV_OMR_feyrer_pop_Ftest IV_tau_feyrer_pop_Ftest
#delimit ;
estout `columns' using "$output_tab/`table'_Ftest.tex", replace stats(F_eff N, labels("F-effective" "Observations") fmt(%9.1f %9.0fc)) 
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons ln_* *.i *.t)	noomitted ;
#delimit cr

* Log file (first stage tests)
capture log using "$output_tab/`table'_Ftest.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) 									/// 
	   stats(F_eff arf arfp N, labels("F-effective" " AR-F" "AR-F p-value" "Observations") fmt(%9.1f %9.1f %9.3f %9.0fc)) 	///
	   drop(_cons ln_* *.i *.t) substitute("IV_" "   ")
capture log close


*-------------------Table 3 - Country-specific results - R&D--------------------
local table table_3 										 // table name

foreach reg in stage1 baseline naive fe_ppml fe_reg {
	local columns`reg'
	foreach var in tot hed bus gov {
		estimates use "$output_est/RD`var'_`reg'_boot_bayes" // load estimation results
		estimates store RD`var'_`reg'						 // store results to create columns below
		local columns`reg' `columns`reg'' RD`var'_`reg'
	}
}

* Stage 1
#delimit ;
estout `columnsstage1' using "$output_tab/`table'A_stage1.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons rta_ml eu wto 1.brdr*) 
		rename(ln_var_itbrdr "$\!ln(R\&D_{it})*BRDR_{ij}\$")
		varlabels(, nolast elist("$\!ln(R\&D_{it})*BRDR_{ij}\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t") noomitted ;
#delimit cr


* Stage 2 - Baseline
#delimit ;
estout `columnsbaseline' using "$output_tab/`table'A_stage2.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons ln_A_i ln_L_i ln_K_i ln_OMR_i) 
		rename(ln_var_it "$\!ln(R\&D_{it})\$" tot "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t") noomitted ;
#delimit cr


* Stage 2 - Naive gravity
#delimit ;
estout `columnsnaive' using "$output_tab/`table'B_naive.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons rta_ml eu wto ln_remote_i ln_gdp_i) 
		rename(ln_var_itbrdr "$\!ln(R\&D_{it})*BRDR_{ij}\$" ln_var_it "$\!ln(R\&D_{it})\$" tot "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t") noomitted ;
#delimit cr


* Stage 2 - FEs with ppml
#delimit ;
estout `columnsfe_ppml' using "$output_tab/`table'C_fe_ppml.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons ln_A_i ln_L_i ln_K_i ln_OMR_i) 
		rename(ln_var_it "$\!ln(R\&D_{it})\$" tot "Total effect") 
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t") noomitted ;
#delimit cr


* Stage 2 - FEs with OLS
#delimit ;
estout `columnsfe_reg' using "$output_tab/`table'D_fe_ols.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons ln_A_i ln_L_i ln_K_i ln_OMR_i) 
		rename(ln_var_it "$\!ln(R\&D_{it})\$" tot "Total effect") 
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t") noomitted ;
#delimit cr

* Note: for a log file see below the log files of Online Appendix Tables D.1-D.3


*---------------------------Online Appendix Table D.1---------------------------
local table table_D1 										 // table name

foreach reg in stage1 baseline naive fe_ppml fe_reg {
	local columns`reg'
	foreach var in tot hed bus gov {
		estimates use "$output_est/RD`var'_`reg'_boot_bayes" // load estimation results
		estimates store RD`var'_`reg'						 // store results to create columns below
		local columns`reg' `columns`reg'' RD`var'_`reg'
	}
}


* Stage 1
#delimit ;
estout `columnsstage1' using "$output_tab/`table'_stage1.tex", replace stats(N, labels("Observations") fmt(%9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons 1.brdr*) 
		rename(rta_ml 	"$\!RTA_{ijt}\$"
			   eu 		"$\!EU_{ijt}\$"
			   wto 		"$\!WTO_{ijt}\$"
			   ln_var_itbrdr "$\!ln(R\&D_{it})*BRDR_{ij}\$")
		varlabels(, nolast elist("$\!ln(R\&D_{it})*BRDR_{ij}\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t" "{ijt"  "{ij,t") noomitted ;
#delimit cr


* Stage 2 - Baseline
#delimit ;
estout `columnsbaseline' using "$output_tab/`table'_stage2.tex", replace stats(N, labels("Observations") fmt(%9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(ln_A_i 	 "$\!ln(A_{it})\$" 
			   ln_L_i 	 "$\!ln(L_{it})\$" 
			   ln_K_i 	 "$\!ln(K_{it})\$"
			   ln_OMR_i  "$\!ln(\Pi_{it}^{1-\sigma})\$"
			   ln_var_it "$\!ln(R\&D_{it})\$" 
			   tot 		 "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})") noomitted ;
#delimit cr

* Log files
capture log using "$output_tab/`table'_stage1&stage2.log", replace
estout `columnsstage1' `columnsbaseline', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** .05 *** .01) ///
		stats(tot N, labels("Total effect" "Obs") fmt(%9.3g %9.3g %9.0fc)) drop(_cons 1.brdr*)
capture log close


*---------------------------Online Appendix Table D.2---------------------------
local table table_D2 										// table name

foreach reg in stage1 baseline naive fe_ppml fe_reg {
	local columns`reg'
	foreach var in tot hed bus gov {
		estimates use "$output_est/RD`var'_`reg'_boot_bayes" // load estimation results
		estimates store RD`var'_`reg'						 // store results to create columns below
		local columns`reg' `columns`reg'' RD`var'_`reg'
	}
}

* Stage 2 - Naive gravity
#delimit ;
estout `columnsnaive' using "$output_tab/`table'.tex", replace stats(N, labels("Observations") fmt(%9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(rta_ml 		 "$\!RTA_{ijt}\$"
			   eu 			 "$\!EU_{ijt}\$"
			   wto 			 "$\!WTO_{ijt}\$"
			   ln_remote_i 	 "$\!ln(remote_{it})\$"
			   ln_gdp_i 	 "$\!ln(GDP_{it})\$"
			   ln_var_itbrdr "$\!ln(R\&D_{it})*BRDR_{ij}\$"
			   ln_var_it 	 "$\!ln(R\&D_{it})\$" 
			   tot 		 "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "{ijt"  "{ij,t") noomitted ;
#delimit cr

* Log files
capture log using "$output_tab/`table'.log", replace
estout `columnsnaive', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** .05 *** .01) ///
		stats(tot N, labels("Total effect" "Obs") fmt(%9.3g %9.3g %9.0fc)) drop(_cons)
capture log close


*---------------------------Online Appendix Table D.3---------------------------
local table table_D3 										// table name

foreach reg in stage1 baseline naive fe_ppml fe_reg {
	local columns`reg'
	foreach var in tot hed bus gov {
		estimates use "$output_est/RD`var'_`reg'_boot_bayes" // load estimation results
		estimates store RD`var'_`reg'						 // store results to create columns below
		local columns`reg' `columns`reg'' RD`var'_`reg'
	}
}

* Stage 2 - FEs with ppml
#delimit ;
estout `columnsfe_ppml' using "$output_tab/`table'_fe_ppml.tex", replace stats(N, labels("Observations") fmt(%9.0fc)) 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(ln_A_i 	 "$\!ln(A_{it})\$" 
			   ln_L_i 	 "$\!ln(L_{it})\$" 
			   ln_K_i 	 "$\!ln(K_{it})\$"
			   ln_OMR_i  "$\!ln(\Pi_{it}^{1-\sigma})\$"
			   ln_var_it "$\!ln(R\&D_{it})\$" 
			   tot 		 "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})") noomitted ;
#delimit cr


* Stage 2 - FEs with OLS
#delimit ;
estout `columnsfe_reg' using "$output_tab/`table'_fe_ols.tex", replace stats(N, labels("Observations") fmt(%9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		rename(ln_A_i 	 "$\!ln(A_{it})\$" 
			   ln_L_i 	 "$\!ln(L_{it})\$" 
			   ln_K_i 	 "$\!ln(K_{it})\$"
			   ln_OMR_i  "$\!ln(\Pi_{it}^{1-\sigma})\$"
			   ln_var_it "$\!ln(R\&D_{it})\$" 
			   tot 		 "Total effect")
		varlabels(, nolast elist("$\!ln(R\&D_{it})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t"  "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})") noomitted ;
#delimit cr	

* Log files
capture log using "$output_tab/`table'_fe_ppml_fe_ols.log", replace
estout `columnsfe_ppml' `columnsfe_reg', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* 0.10 ** .05 *** .01) ///
		stats(tot N, labels("Total effect" "Obs") fmt(%9.3g %9.3g %9.0fc)) drop(_cons)
capture log close


*---------------------Table 4 - Aggregate Trade Elasticities--------------------
local table table_4 										// table name

* With aggregate results
local columns constrained_CRS constrained_noCRS tot_AR1_CRS tot_AR1_noCRS
local sigmas

foreach name of local columns {
	estimates use "$output_est/`name'_boot_bayes" 			// load estimation results
	estimates store `name' 									// store results to create columns below
	
	* Back out sigma
	nlcom 1/(1 + _b[a:_cons]), post
	estimates store `name'_sigma 							// store results to create columns below
	local sigmas `sigmas' `name'_sigma
	
	* CRS
	capture {
		estimates use "$output_est/`name'_crs_boot_bayes" 	// load estimation results
		estimates store `name'_crs 							// store results to create columns below
	}
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'_core.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(a:_cons 	"$\widetilde{\alpha}$" 
			   bL:_cons "$\delta$"
			   bg:_cons "$\gamma$"
			   rho:_cons "$\rho$")
		varlabels(, nolast elist("$\rho$" \midrule)) 
		substitute(" ." "n/a") noomitted ;
#delimit cr

* Sigmas
#delimit ;
estout `sigmas' using "$output_tab/`table'_sigmas.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(_nl_1 "$\sigma = 1/(1+\alpha)$")
		substitute("+\alpha" "+\widetilde{\alpha}")
		varlabels(, nolast) noomitted ;
#delimit cr

* CRS
#delimit ;
estout constrained_CRS_sigma constrained_noCRS_crs tot_AR1_CRS_sigma tot_AR1_noCRS_crs using "$output_tab/`table'_crstest.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_nl_1) 
		rename(_cons "$\gamma+\delta$")
		varlabels(, nolast elist("$\!\gamma + \delta\$" \midrule))
		substitute("\!" "") noomitted ;
#delimit cr

* Observations
#delimit ;
estout `columns' using "$output_tab/`table'_stats.tex", replace 
		stats(CRS_p N, labels("$\!H_{0}: \gamma + \delta = 1\$ (p-value)" "Observations") fmt(%9.3fc %9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons*) 
		substitute("\!" "" " ." "n/a") noomitted ;
#delimit cr

* Log
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) ///
		stats(CRS_p N, labels("CRS" "Observations") fmt(%9.3fc %9.0fc))
capture log close


*---------------------Table 5 - Sectoral Trade Elasticities---------------------
*--------------------------------Panel A: CRS-----------------------------------
local table table_5A_CRS 									// table name
local columns
local sigmas
foreach s in tot man ser agr min { 							// for each sectoral estimate
	estimates use "$output_est/`s'_AR1_CRS_boot_bayes" 		// load estimation results
	estimates store `s' 									// store results to create columns below
	local columns `columns' `s'
	
	* Back out sigma
	nlcom 1/(1 + _b[a:_cons]), post
	estimates store `s'_sigma 								// store results to create columns below
	local sigmas `sigmas' `s'_sigma	
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'_core.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none)
		rename(a:_cons "$\widetilde{\alpha}$" 
			   bg:_cons "$\gamma$"
			   rho:_cons "$\rho$")
		varlabels(, nolast elist("$\rho$" \midrule)) 
		substitute(" . " "n/a") noomitted ;
#delimit cr

* Sigmas
#delimit ;
estout `sigmas' using "$output_tab/`table'_sigmas.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(_nl_1 "$\sigma = 1/(1+\alpha)$")
		substitute("+\alpha" "+\widetilde{\alpha}")
		varlabels(, nolast) noomitted ;
#delimit cr	

* Log
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) ///
		stats(N, labels("Observations") fmt(%9.3g %9.0fc))
capture log close


*-------------------------------Panel B: no CRS---------------------------------
local table table_5B_noCRS 								 	// table name

local columns
local sigmas
local crs
foreach s in tot man ser agr min { 						 	// for each sectoral estimate
	estimates use "$output_est/`s'_AR1_noCRS_boot_bayes" 	// load estimation results
	estimates store `s' 								 	// store results to create columns below
	local columns `columns' `s'
	
	* Back out sigma
	nlcom 1/(1 + _b[a:_cons]), post
	estimates store `s'_sigma 							 	// store results to create columns below
	local sigmas `sigmas' `s'_sigma

	* CRS
	estimates use "$output_est/`s'_AR1_noCRS_crs_boot_bayes" // load estimation results
	estimates store `s'_crs 							 	// store results to create columns below
	local crs `crs' `s'_crs	
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'_core.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(a:_cons "$\widetilde{\alpha}$" 
			   bg:_cons "$\gamma$"
			   bL:_cons "$\delta$"
			   rho:_cons "$\rho$")
		varlabels(, nolast elist("$\rho$" \midrule)) 
		substitute(" . " "n/a") noomitted ;
#delimit cr

* Sigmas
#delimit ;
estout `sigmas' using "$output_tab/`table'_sigmas.tex", replace
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(_nl_1 "$\sigma = 1/(1+\alpha)$")
		substitute("+\alpha" "+\widetilde{\alpha}")
		varlabels(, nolast) noomitted ;
#delimit cr

* CRS
#delimit ;
estout `crs' using "$output_tab/`table'_crstest.tex", replace 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) 
		rename(_cons "$\gamma + \delta$")
		varlabels(, nolast) noomitted ;
#delimit cr

* Observations
#delimit ;
estout `columns' using "$output_tab/`table'_stats.tex", replace 
		stats(CRS_p N, labels("$\!H_{0}: \gamma + \delta = 1\$ (p-value)" "Observations") fmt(%9.3fc %9.0fc))
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons) 
		substitute("\!" "" " . " "n/a") noomitted ;
#delimit cr

* Log
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) ///
		stats(CRS_p N, labels("CRS test" "Observations") fmt(%9.3fc %9.0fc))
capture log close


*--------------------Online Appendix Table C.1 - Robustness---------------------
local table table_C1										// table name

* Program to repost column labels below for point estimates from AR1 process
capture prog drop replace_b
program replace_b, eclass
	ereturn repost b = b, rename
end

* Program to repost column labels below for standard errors from AR1 process
capture prog drop replace_se
program replace_se, eclass
	estadd matrix se, replace 
end

local stdev _boot_bayes 									// way to compute standard errors
local columns baseline`stdev' baseline_hat`stdev' baseline_it`stdev' K_other`stdev' L_other`stdev' baseline_boot baseline baseline_weight_se_fe AR1`stdev'

foreach name of local columns {
	estimates use "$output_est/`name'" 						// load estimation results
	
	if substr("`name'", 1, 3) == "AR1" {
		* Store estimation results in matrix b and access all colnames
		mat b = e(b)
		local colnames: colfullnames b

		* Substitute particular string in colnames list
		local colnames : subinstr local colnames "bK:_cons" 	"ln_K_i", all
		local colnames : subinstr local colnames "bL:_cons" 	"ln_L_i", all
		local colnames : subinstr local colnames "bOMR:_cons" 	"ln_OMR_i", all
		local colnames : subinstr local colnames "rho:_cons" 	"rho", all

		* Rename matrix colnames with new local list and repost
		matrix colnames b = `colnames'
		matrix colnames b = b:
		replace_b
		
		* Update column labels for standard errors
		matrix se = e(se)
		matrix colnames se = `colnames'
		matrix colnames se = b:
		replace_se
	}
	estimates store `name' 									// store results to create columns below
}

* Tex Table
#delimit ;
estout `columns' using "$output_tab/`table'.tex", replace stats(N, labels("Observations") fmt(%9.0fc)) 
		cells(b(star fmt(3)) se(par fmt(3))) starlevels($^{\ast}$ .10 $^{\ast\ast}$ .05 $^{\ast\ast\ast}$ .01)
		style(tex) mlabels(, none) collabels(, none) eqlabels(, none) drop(_cons)
		rename(ln_A_i 	"$\!ln(A_{it})\$" 
			   ln_L_i 	"$\!ln(L_{it})\$" 
			   ln_K_i 	"$\!ln(K_{it})\$"
			   ln_OMR_i "$\!ln(\Pi_{it}^{1-\sigma})\$" 
			   rho "$\!ln(\widehat{A}_{it-1})\$")
		varlabels(, nolast elist("$\!ln(\widehat{A}_{it-1})\$" \midrule)) 
		substitute("\!" ""  "{it" "{i,t" "(\Pi_{i,t}^{1-\sigma})" "(\widehat{\Pi_{i,t}^{1-\sigma}})") 
		noomitted ;
#delimit cr

* Log
capture log using "$output_tab/`table'.log", replace
estout `columns', cells(b(star fmt(3)) se(par fmt(3))) starlevels(* .10 ** .05 *** .01) ///
		stats(N, labels("Observations") fmt(%9.3g %9.0fc)) drop(_cons)
capture log close


* Eliminate stored results from memory
clear results
