version 16.1 										// version control

*-------------------------------------------------------------------------------
/* Replication package for project:
   Freeman, R., Larch., M., Theodorakopoulos, A., Yoto, Y., 2025.
   Unlocking New Methods to Estimate Country-specific Effects and Trade 
   Elasticities with the Structural Gravity Model. 
   Journal of Applied Econometrics. 
  
   ----------------------Information about this code file-----------------------
   tasks : master script to set directories, install relevant packages and run 
		   all results in the project.
   output: All results and tables in the manuscript and appendix. 
*/
*-------------------------------------------------------------------------------

*-----------------------------------Set up--------------------------------------
capture log close
clear all
set varabbrev off, permanently						// turn off variable abbreviations to avoid unexpected behaviour due to ambiguity in variable & scalar names
set type double  , permanently
set more off 	 , permanently
set rmsg on 	 , permanently


*--------------------------------Directories------------------------------------
* Define project file directory
/* Note: we use package 'here' to set the project folder path. Otherwise, fill  
   in the path manually in the macro "global project" below.
*/
capture net install here, from("https://raw.githubusercontent.com/korenmiklos/here/master/") 	// requires writing rights
here												// sets the root of the project folder into a global macro called here
display "$here" 									// check

* Set macros for path directories of different folders
/* Note: within the project folder, there are four key subfolders, which 
   include: code, data, output, and temp.	
*/
global project 	  "$here" 							// project folder directory - If package 'here' does not work, change the project path directory manually!
global code 	  "$project/code" 					// folder for code
global data 	  "$project/data" 					// folder for raw data
global output 	  "$project/output" 				// folder for output
global output_est "$project/output/estimates" 		// folder for output - estimates
global output_tab "$project/output/tables"  		// folder for output - tables
global temp 	  "$project/temp" 					// folder for temporary files (to be deleted at the end of the project)


*--------------Create folders to store data, results & temp files---------------
foreach var in data output output_est output_tab temp {
	capture mkdir "$`var'"
}


*-------Install necessary packages (Administrator rights required)--------------
/* The section below describes and installs all packages needed for replication.
   Note: the "copy" command may not function with older Stata versions, so you
   you should comment it out in the do file "[1.0] data" and download the data 
   manually.
*/
ssc install elabel, replace 						// (re-)install package
ssc install estout, replace 						// (re-)install package
ado update elabel, update 							// provide most recent update
ado update estout, update 							// provide most recent update
ado update st0171_1, update 						// provide most recent update for rivtest

* Install reghdfe
capture ado uninstall reghdfe
net install reghdfe, from("https://raw.githubusercontent.com/sergiocorreia/reghdfe/master/src/")

* Install ivereg2 and ivreghdfe
capture ado uninstall ivreghdfe
capture ssc install ivreg2 							// install ivreg2, the core package
net install ivreghdfe, from(https://raw.githubusercontent.com/sergiocorreia/ivreghdfe/master/src/)

* Install parallel, if using the parallel() option; don't install from SSC
cap ado uninstall parallel
net install parallel, from(https://raw.github.com/gvegayon/parallel/stable/) replace
mata mata mlib index

* Ensures that installed packages have an exact version as listed in "requirements.txt"
ssc install require, replace
// require using requirements_test.txt, stata list exact replace adopath(BASE PERSONAL PLUS SITE) // lists exact versions of installed packages when authors executed code.
require using "$code/requirements.txt", install // install the packages if not present or if version requirements are not met (as listed in requirements.txt)


*---------------------------------Run code--------------------------------------
* Clear programs already in memory
program drop _all

* Clear timer
timer clear

* Download, store, clean and prepare raw data for main analysis
timer on 1
do "$code/[1.0] data.do"
timer off 1


* Estimations - results in manuscript Tables 1 and 3; & online appendix Table C.1 (except for columns 6-8)
timer on 2
do "$code/[2.0] estimations_boot_bayes.do"
do "$code/[2.0] estimations_weak_IV_Ftest.do" 		// performs the weak IV F test for IV results in Table 2 (columns 2-7)
timer off 2


* Estimations - results in columns 6-8 in the online appendix Table C.1
timer on 3
do "$code/[2.1] estimations_boot.do" 				// results in column 6 in the online appendix Table C.1
do "$code/[2.1] estimations_noboot.do" 				// results in column 7 in the online appendix Table C.1
do "$code/[2.1] estimations_weight_se_fe.do"  		// results in column 8 in the online appendix Table C.1
timer off 3


* Estimations with country-specific variable (R&D) - results in manuscript Table 3; & online appendix Tables D.1-D.3
timer on 4
do "$code/[2.2] estimations_r&d_boot_bayes.do" 
timer off 4


* Estimations at the sectoral level - results in manuscript Tables 4 and 5.
timer on 5
do "$code/[2.3] estimations_sectoral_boot_bayes.do" 
timer off 5


* Export tables in tex
timer on 6
do "$code/[3.0] export_tex_tables.do" 
timer off 6


* Total computation time (create a log file)
capture log using "$output_est/_estimates_timer.log", replace 	// log file

timer list
local plus 
forvalues i = 1 / 6 {
	if r(t`i') != . local ttot = `ttot' `plus' r(t`i') 
	local plus +
	display `ttot'
}

display "Total execution time is: "%9.1f `ttot' " which in minutes is: "%9.1f `=`ttot'/60' " and in hours is: "%9.1f `=`ttot'/60/60'

* Close log file
capture log close

* End of project and exit Stata
clear all
exit
